@@ -1,11 +1,5 @@
 /** @format */
 
-/*
- * Store tests
- *
- * @group unit
- */
-
 import { createTestingPinia } from "@pinia/testing";
 
 // import any store you want to interact with in tests
@@ -29,11 +23,11 @@ describe("Session Store", () => {
             "gl_all"
         ]);
         expect(session.preferences).toStrictEqual({
-            "numberformat" : "1000.00",
-            "printer" : null,
-            "stylesheet" : "ledgersmb.css",
-            "dateformat" : "yyyy-mm-dd",
-            "language" : null
+            numberformat: "1000.00",
+            printer: null,
+            stylesheet: "ledgersmb.css",
+            dateformat: "yyyy-mm-dd",
+            language: null
         });
         expect(session.hasRole("cash_all")).toBe(true);
         expect(session.hasRole("invalid role")).toBe(false);
