@@ -1,5 +1,5 @@
 /** @format */
-/* eslint global-require:0, no-param-reassign:0, no-unused-vars:0 */
+/* eslint global-require:0, no-unused-vars:0 */
 /* global getConfig */
 
 const TARGET = process.env.npm_lifecycle_event;
@@ -9,7 +9,6 @@ if (TARGET !== "readme") {
     const glob = require("glob");
     const path = require("path");
     const webpack = require("webpack");
-
     const BundleAnalyzerPlugin =
         require("webpack-bundle-analyzer").BundleAnalyzerPlugin;
     const { CleanWebpackPlugin } = require("clean-webpack-plugin"); // installed via npm
@@ -25,24 +24,24 @@ if (TARGET !== "readme") {
     const { VueLoaderPlugin } = require("vue-loader");
     // eslint-disable-next-line
     const { WebpackDeduplicationPlugin } = require("webpack-deduplication-plugin");
-
-    const argv = require("yargs").argv;
+    const yargs = require("yargs/yargs");
+    const { hideBin } = require("yargs/helpers");
+    const argv = yargs(hideBin(process.argv)).argv;
     const prodMode =
         process.env.NODE_ENV === "production" ||
         argv.p ||
         argv.mode === "production";
+    const parallelJobs = process.env.CI ? 2 : true;
 
     // Make sure all modules follow desired mode
     process.env.NODE_ENV = prodMode ? "production" : "development";
-    const parallelJobs = process.env.CI ? 2 : true;
 
     /* FUNCTIONS */
     var includedRequires = [];
 
-    /* eslint-disable-next-line no-inner-declarations */
     function findDataDojoTypes(fileName) {
         var content = "" + fs.readFileSync(fileName);
-        // Return unique data-dojo-type refereces
+        // Return unique data-dojo-type references
         return (
             content.match(
                 /(?<=['"]?data-dojo-type['"]?\s*=\s*")([^"]+)(?=")/gi
@@ -50,7 +49,6 @@ if (TARGET !== "readme") {
         ).filter((x, i, a) => a.indexOf(x) === i);
     }
 
-    /* eslint-disable-next-line no-inner-declarations */
     function getPOFilenames(_path, extension) {
         return fs
             .readdirSync(_path)
@@ -64,23 +62,24 @@ if (TARGET !== "readme") {
             .sort();
     }
 
-    /* eslint-disable-next-line no-inner-declarations */
     function globCssEntries(globPath) {
         const files = glob.sync(globPath);
         let entries = {};
 
         for (var i = 0; i < files.length; i++) {
             const entry = files[i];
-            const dirName = path.dirname(entry).replace(/\.\/css\/?/,"");
-            const keyName = (dirName ? dirName + "/" : "" ) + path.basename(entry, path.extname(entry));
+            const dirName = path.dirname(entry).replace(/\.\/css\/?/, "");
+            const keyName =
+                (dirName ? dirName + "/" : "") +
+                path.basename(entry, path.extname(entry));
             entries[keyName] = path.join(__dirname, entry);
         }
         return entries;
     }
 
     // Compute used data-dojo-type
-    glob.sync("**/*.html", {
-        ignore: ["lib/ui-header.html", "js/**", "node_modules/**"],
+    glob.sync("{**/*.html,src/**/*.vue}", {
+        ignore: ["lib/ui-header.html", "js/**", "node_modules/**"]
         // cwd: "."
     }).map(function (filename) {
         const requires = findDataDojoTypes(filename);
@@ -125,7 +124,6 @@ if (TARGET !== "readme") {
             return /node_modules/.test(file) || /_scripts/.test(file);
         }
     };
-
     const vue = {
         test: /\.vue$/,
         loader: "vue-loader",
@@ -135,18 +133,14 @@ if (TARGET !== "readme") {
             }
         }
     };
-
-
     const css = {
         test: /\.css$/i,
         use: [MiniCssExtractPlugin.loader, "css-loader"]
     };
-
     const images = {
         test: /\.(png|jpe?g|gif)$/i,
         type: "asset"
     };
-
     const html = {
         test: /\.html$/,
         use: [
@@ -158,36 +152,35 @@ if (TARGET !== "readme") {
             }
         ]
     };
-
     const svg = {
         test: /\.svg$/,
         type: "asset/resource"
     };
-
     /* PLUGINS */
 
     const CleanWebpackPluginOptions = {
         dry: false,
         verbose: false
     }; // delete all files in the js directory without deleting this folder
-
     const StylelintPluginOptions = {
         files: "**/*.css"
     };
-
     // Copy non-packed resources needed by the app to the release directory
     const CopyWebpackPluginOptions = {
         patterns: [
             { context: "node_modules", from: "dijit/icons/**/*", to: "." },
             { context: "node_modules", from: "dijit/nls/**/*", to: "." },
             { context: "node_modules", from: "dojo/nls/**/*", to: "." },
-            { context: "node_modules", from: "dojo/resources/**/*", to: "." }
+            {
+                context: "node_modules",
+                from: "dojo/resources/**/*",
+                to: "."
+            }
         ],
         options: {
             concurrency: 100
         }
     };
-
     const DojoWebpackPluginOptions = {
         loaderConfig: require("./js-src/lsmb/webpack.loaderConfig.js"),
         environment: { dojoRoot: "js" }, // used at run time for non-packed resources (e.g. blank.gif)
@@ -195,28 +188,25 @@ if (TARGET !== "readme") {
         locales: getPOFilenames("src/locales", ".json"),
         noConsole: true
     };
-
     // dojo/domReady (only works if the DOM is ready when invoked)
     const NormalModuleReplacementPluginOptionsDomReady = function (data) {
         const match = /^dojo\/domReady!(.*)$/.exec(data.request);
-        /* eslint-disable-next-line no-param-reassign */
+
         data.request = "dojo/loaderProxy?loader=dojo/domReady!" + match[1];
     };
-
     const NormalModuleReplacementPluginOptionsSVG = function (data) {
         var match = /^svg!(.*)$/.exec(data.request);
-        /* eslint-disable-next-line no-param-reassign */
+
         data.request =
             "dojo/loaderProxy?loader=svg&deps=dojo/text%21" +
             match[1] +
             "!" +
             match[1];
     };
-
     const UnusedWebpackPluginOptions = {
         // Source directories
         directories: [
-            path.join(__dirname, "js-src/lsmb"), 
+            path.join(__dirname, "js-src/lsmb"),
             path.join(__dirname, "src")
         ],
         // Exclude patterns
@@ -224,14 +214,12 @@ if (TARGET !== "readme") {
         // Root directory (optional)
         root: __dirname
     };
-
     // Generate entries from file pattern
     const mapFilenamesToEntries = (pattern) =>
         glob.sync(pattern).reduce((entries, filename) => {
             const [, name] = filename.match(/([^/]+)\.css$/);
             return { ...entries, [name]: filename };
         }, {});
-
     const _dijitThemes = "+(claro|nihilo|soria|tundra)";
     const lsmbCSS = {
         ...mapFilenamesToEntries(path.resolve("css/*.css")),
@@ -245,7 +233,6 @@ if (TARGET !== "readme") {
             )
         )
     };
-
     // Compile bootstrap module as a virtual one
     const VirtualModulesPluginOptions = {
         "./bootstrap.js":
@@ -278,7 +265,6 @@ if (TARGET !== "readme") {
         new webpack.NormalModuleReplacementPlugin(/^dojo\/text!/, function (
             data
         ) {
-            /* eslint-disable-next-line no-param-reassign */
             data.request = data.request.replace(
                 /^dojo\/text!/,
                 "!!raw-loader!"
@@ -304,11 +290,14 @@ if (TARGET !== "readme") {
 
         // Handle HTML
         new HtmlWebpackPlugin({
-            inject: false, // Tags are injected manually in the content below
+            inject: "body", // Tags are injected manually in the content below
             minify: false, // Adjust t/16-schema-upgrade-html.t if prodMode is used,
             filename: "ui-header.html",
             mode: prodMode ? "production" : "development",
-            excludeChunks: [...Object.keys(lsmbCSS),...Object.keys(globCssEntries("./css/**/*.css"))],
+            excludeChunks: [
+                ...Object.keys(lsmbCSS),
+                ...Object.keys(globCssEntries("./css/**/*.css"))
+            ],
             template: "lib/ui-header.html"
         }),
 
@@ -342,34 +331,30 @@ if (TARGET !== "readme") {
                     return "'" + po + "'";
                 }
             ),
-            __VUE_PROD_DEVTOOLS__: true
+            __VUE_PROD_DEVTOOLS__: JSON.stringify(false),
+            __VUE_OPTIONS_API__: JSON.stringify(true),
+            __VUE_I18N_FULL_INSTALL__: JSON.stringify(true),
+            __VUE_I18N_LEGACY_API__: JSON.stringify(false),
+            __VUE_PROD_HYDRATION_MISMATCH_DETAILS__: (
+                process.env.NODE_ENV !== "production" ? "true" : "false"),
+            __INTLIFY_PROD_DEVTOOLS__: JSON.stringify(false),
         })
     ];
-
     var pluginsProd = [
         ...pluginsCommon,
 
         // Statics from build.
         new webpack.DefinePlugin({
-            __VUE_PROD_DEVTOOLS__: true
         })
     ];
-
-
     var pluginsDev = [
         ...pluginsCommon,
 
         new UnusedWebpackPlugin(UnusedWebpackPluginOptions),
 
         new webpack.DefinePlugin({
-            __VUE_I18N_FULL_INSTALL__: JSON.stringify(true),
-            __INTLIFY_PROD_DEVTOOLS__: JSON.stringify(false),
-            __VUE_I18N_LEGACY_API__: JSON.stringify(false),
-            __VUE_OPTIONS_API__: true,
-            __VUE_PROD_DEVTOOLS__: true
         })
     ];
-
     var pluginsList = prodMode
         ? [
               // Clean js before building (must be first)
@@ -394,7 +379,7 @@ if (TARGET !== "readme") {
         runtimeChunk: "multiple",
         splitChunks: {
             cacheGroups: {
-                node_modules: {
+                nodeModules: {
                     test(module) {
                         // `module.resource` contains the absolute path of the file on disk.
                         // Note the usage of `path.sep` instead of / or \, for cross-platform compatibility.
@@ -417,7 +402,6 @@ if (TARGET !== "readme") {
             }
         }
     };
-
     /* WEBPACK CONFIG */
 
     const webpackConfigs = {
@@ -450,9 +434,8 @@ if (TARGET !== "readme") {
         resolve: {
             alias: {
                 vue$: "vue/dist/vue.cjs.js",
-                pinia$: "pinia/dist/pinia.cjs",
-                "vue-i18n": "vue-i18n/dist/vue-i18n.cjs",
-                "@pinia": path.join(__dirname, "node_modules/@pinia"), // Fix eslint importer
+                "vue-router": "vue-router/dist/vue-router.cjs",
+                "vue-i18n": "vue-i18n/dist/vue-i18n.esm-bundler.js",
                 "@": path.join(__dirname, "src/")
             },
             extensions: [".js", ".vue"],
@@ -495,38 +478,43 @@ if (TARGET !== "readme") {
             },
             hot: true,
             host: "0.0.0.0",
+            liveReload: true,
             port: 9000,
-            proxy: {
-                "/*.pl": {
+            proxy: [
+                {
+                    context: ["/*.pl"],
                     target: "http://proxy"
                 },
-                "/erp/api": {
+                {
+                    context: ["/erp/api"],
                     target: "http://proxy"
                 },
-                "/app/*.pl": {
+                {
+                    context: ["/app/*.pl"],
                     target: "http://proxy",
                     pathRewrite: { "^/app": "" }
                 },
-                "/app/erp/api": {
+                {
+                    context: ["/app/erp/api"],
                     target: "http://proxy",
                     pathRewrite: { "^/app": "" }
                 }
-            },
+            ],
             static: [
                 {
                     directory: __dirname,
-                    publicPath: '/'
+                    publicPath: "/"
                 },
                 {
                     directory: __dirname,
-                    publicPath: '/app'
+                    publicPath: "/app"
                 }
             ],
             watchFiles: [
                 "webpack.config.js",
-                "**/*",
-                "!js/*",
-                "node_modules/**/*"
+                "**/*.{html,css,gif,jpg,png,svg,json}",
+                "js-src/**/*.js",
+                "src/**/*.{js,vue}"
             ]
         },
 
