@@ -203,10 +203,32 @@ named argument 'renderer' to the C<LedgerSMB::Report->render> method.
 Renders the report as a document or UI element, depending on whether
 the request's C<format> property has a non-false value.
 
+
+=item parse_amount($amount)
+
+Parses the $amount given the session user's number formatting settings.
+
+=item parse_date($date)
+
+Parses the $date given the session user's date formatting settings.
+
+=item format_amount($amount, %args)
+
+formats the $amount given the session user's number formatting settings.
+
+=item format_date($date, %args)
+
+formats the $date given the session user's date formatting settings.
+
+=item formatter_options()
+
+Returns a hashref containing the session user's number and date formatting
+preferences for use in LedgerSMB::Report-s.
+
 =back
 
 
-=head1 Copyright (C) 2006-2017, The LedgerSMB core team.
+=head1 Copyright (C) 2006-2023, The LedgerSMB core team.
 
  # This work contains copyrighted information from a number of sources
  # all used with permission.
@@ -243,22 +265,20 @@ use List::Util qw( pairgrep );
 use Locale::CLDR;
 use Locales unicode => 1;
 use Log::Any;
-use Math::BigFloat;
-use Math::BigInt;
 use PGObject;
 use Plack;
 use URI;
 use URI::Escape;
 
-use LedgerSMB::App_State;
 use LedgerSMB::Locale;
-use LedgerSMB::User;
-use LedgerSMB::Company_Config;
+use LedgerSMB::PGDate;
+use LedgerSMB::PGNumber;
 use LedgerSMB::PSGI::Util qw( template_response );
 use LedgerSMB::Setting;
 use LedgerSMB::Template;
+use LedgerSMB::User;
 
-our $VERSION = '1.11.16';
+our $VERSION = '1.12.15';
 
 my $logger = Log::Any->get_logger(category => 'LedgerSMB');
 my $expiration_parser = DateTime::Format::Duration::ISO8601->new;
@@ -282,6 +302,7 @@ sub new {
     $self->{script} = $request->env->{'lsmb.script'};
     $self->{dbh} = $request->env->{'lsmb.app'};
     $self->{company} = $request->env->{'lsmb.session'}->{company};
+    $self->{_company_config} = $request->env->{'lsmb.settings'};
     $self->{_session_id} = $request->env->{'lsmb.session_id'};
     $self->{_create_session} = $request->env->{'lsmb.create_session_cb'};
     $self->{_logout} = $request->env->{'lsmb.invalidate_session_cb'};
@@ -352,9 +373,6 @@ sub initialize_with_db {
         $self->{pw_expires} = $expiration_parser->parse_duration($pw_expires);
     }
 
-    $self->{_company_config} =
-        LedgerSMB::Company_Config::initialize($self->{dbh});
-
     $self->get_user_info;
 
     $self->{_locale} =
@@ -370,9 +388,7 @@ sub initialize_with_db {
 
 sub get_user_info {
     my ($self) = @_;
-    LedgerSMB::App_State::set_User(
-        $self->{_user} =
-        LedgerSMB::User->fetch_config($self));
+    $self->{_user} = LedgerSMB::User->fetch_config($self);
     return $self->{_user}->{language} ||= 'en';
 }
 
@@ -383,6 +399,8 @@ sub _set_default_locale {
         ->from_header( $self->{_req}->header( 'Accept-Language' ) );
 
     $self->{_user}->{language} = $lang;
+    $self->{_user}->{dateformat} = 'YYYY-MM-DD';
+    $self->{_user}->{numberformat} = '1000.00';
     $self->{_locale}=LedgerSMB::Locale->get_handle($lang);
     $self->error( __FILE__ . ':' . __LINE__
                   . ": Locale ($lang) not loaded: $!\n" )
@@ -651,8 +669,6 @@ sub enabled_languages {
 sub enabled_countries {
     my ($self) = @_;
 
-    local $Math::BigInt::upgrade = undef;
-    local $Math::BigFloat::downgrade = undef;
     my $regions = Locale::CLDR->new($self->{_user}->{language})->all_regions;
     return [
         map {
@@ -697,6 +713,7 @@ sub report_renderer_doc {
         $request->{_wire}->get( 'output_formatter' )->report_doc_renderer(
             $request->{_dbh},
             uc($request->{format}) || 'HTML',
+            $request->formatter_options,
             {
                 SETTINGS => {
                      # default paper size when not configured
@@ -730,9 +747,61 @@ sub render_report {
     return $report->render( renderer => $renderer);
 }
 
+
+sub parse_amount {
+    my ($request, $amount_str) = @_;
+    my $config = $request->{_user};
+
+    return LedgerSMB::PGNumber->from_input(
+        $amount_str,
+        format => $config->{numberformat}
+        );
+}
+
+sub parse_date {
+    my ($request, $date_str) = @_;
+    my $config = $request->{_user};
+
+    return LedgerSMB::PGDate->from_input(
+        $date_str,
+        format => $config->{dateformat}
+        );
+}
+
+sub format_amount {
+    my ($request, $amount, %args) = @_;
+    my $config = $request->{_user};
+
+    return $amount->to_output(
+        format => $config->{numberformat},
+        money_places => $request->{_company_config}->{decimal_places},
+        %args
+        );
+}
+
+sub format_date {
+    my ($request, $date, %args) = @_;
+    my $config = $request->{_user};
+
+    return $date->to_output(
+        format => $config->{dateformat},
+        %args
+        );
+}
+
+sub formatter_options {
+    my ($request) = @_;
+    my $config = $request->{_user};
+
+    return {
+        $config->%{ qw( numberformat dateformat ) },
+        money_places => $request->{_company_config}->{decimal_places},
+    };
+}
+
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2006-2018 The LedgerSMB Core Team
+Copyright (C) 2006-2023 The LedgerSMB Core Team
 
 This file is licensed under the GNU General Public License version 2, or at your
 option any later version.  A copy of the license should have been included with
