@@ -15,18 +15,18 @@ Math::BigFloat and can be used in this way.
 
 =cut
 
-use strict;
+use v5.36;
 use warnings;
 use base qw(PGObject::Type::BigFloat);
+use Scalar::Util qw(blessed);
 
 # try using the GMP library for Math::BigFloat for speed
+use Carp;
 use Math::BigFloat try => 'GMP';
 use Memoize;
 use Number::Format;
 use PGObject::Type::BigFloat;
 
-use LedgerSMB::App_State;
-use LedgerSMB::Company_Config;
 use LedgerSMB::Setting;
 use LedgerSMB::Magic qw( DEFAULT_NUM_PREC );
 
@@ -178,39 +178,26 @@ sub from_input {
     my $self = shift;
     my $string = shift;
 
-    local $@ = undef;
-    return $string if eval { $string->isa(__PACKAGE__) };
-
-    #tshvr4 avoid 'Use of uninitialized value $string in string eq'
+    return $string if blessed $string and $string->isa( __PACKAGE__ );
     if (!defined $string || $string eq '') {
         return undef;
     }
     my %args   = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
-    my $format = ($args{format}) ? $args{format}
-                                 : LedgerSMB::App_State::User()->{numberformat};
-    die 'LedgerSMB::PGNumber No Format Set' if !$format;
-    #return undef if !defined $string;
+    my $format = $args{format} // $args{numberformat};
+    croak 'LedgerSMB::PGNumber No Format Set' if !$format;
+
     my $negate;
     my $pgnum;
     my $newval;
     $negate = 1 if $string =~ /(^\(|DR$)/;
 
-    if (UNIVERSAL::isa($string, 'LedgerSMB::PGNumber')) {
-        return $string;
-    }
-
-    if (UNIVERSAL::isa($string, 'LedgerSMB::PGNumber')) {
-        $pgnum = $string;
-    }
-    else {
-        my $formatter = _formatter(
-            -thousands_sep => $lsmb_formats->{$format}->{thousands_sep},
-            -decimal_point => $lsmb_formats->{$format}->{decimal_sep},
+    my $formatter = _formatter(
+        -thousands_sep => $lsmb_formats->{$format}->{thousands_sep},
+        -decimal_point => $lsmb_formats->{$format}->{decimal_sep},
         );
-        $newval = $formatter->unformat_number($string);
-        $pgnum = LedgerSMB::PGNumber->new($newval);
-        $self->round_mode('+inf');
-    }
+    $newval = $formatter->unformat_number($string);
+    $pgnum = LedgerSMB::PGNumber->new($newval);
+    $self->round_mode('+inf');
 
     bless $pgnum, $self;
     $pgnum->bmul(-1) if $negate;
@@ -232,6 +219,10 @@ Override user's default output format with specified format for this number.
 
 Specifies the number of places to round
 
+=item money_places
+
+Specifies the number of decimal places for for money
+
 =item money
 
 Specifies to round to configured number format for money
@@ -240,8 +231,6 @@ Specifies to round to configured number format for money
 
 Specifies the negative format
 
-=item locale
-
 =back
 
 =cut
@@ -252,13 +241,11 @@ sub to_output {
     my %args  = (ref($_[0]) eq 'HASH')? %{$_[0]}: @_;
     my $is_neg = $self->is_neg;
 
-    my $format = ($args{format}) ? $args{format}
-                              : LedgerSMB::App_State::User()->{numberformat};
-    die 'LedgerSMB::PGNumber No Format Set, check numberformat in user_preference' if !$format;
+    my $format = $args{format} // $args{numberformat};
+    croak 'LedgerSMB::PGNumber No Format Set, check numberformat in user_preference' if !$format;
 
     my $places = undef;
-    $places = $LedgerSMB::Company_Config::settings->{decimal_places}
-       if $args{money};
+    $places = $args{money_places} if $args{money};
     $places = ($args{places}) ? $args{places} : $places;
     my $str = $self->bstr;
     my $dplaces = $places;
