@@ -74,16 +74,12 @@ sub _not_implemented {
 }
 
 sub _get_invoices_by_id {
-    my ($env, $params) = @_;
-
-    return [ HTTP_BAD_REQUEST,
-          [ ],
-          [ ] ]
-      if !$params->{id};
-
-    my $r = Plack::Request::WithEncoding->new($env);
+    my ($env, $r, $c, $body, $params) = @_;
     my %inv = ( id => $params->{id} );
 
+    return error( $r, HTTP_BAD_REQUEST, [],
+                  [ q|'id' parameter missing| ])
+        if defined $params->{id} and $params->{id} eq '';
 
     my $query = q|
         SELECT 'customer' as type,
@@ -334,38 +330,11 @@ sub _get_invoices_by_id {
 
     return [ HTTP_OK,
              [ 'Content-Type' => 'application/json' ],
-             [ json()->canonical->encode(\%inv) ] ];
+             \%inv ];
 }
 
 sub _post_invoices {
-    my ($env) = @_;
-    my $r = Plack::Request::WithEncoding->new($env);
-    my $c = LedgerSMB::Company->new(dbh => $env->{'lsmb.db'});
-
-    {
-        my $ct = $r->headers->content_type;
-        unless ($ct eq 'application/json') {
-            return error(
-                $r,
-                HTTP_UNSUPPORTED_MEDIA_TYPE,
-                {
-                    msg     => 'Unexpected Content-Type header',
-                    details => "Content-Type value '$ct' provided, but 'application/json expected"
-                });
-        }
-    }
-    my $body = json()->decode($r->content);
-    my ($result, $errors, $warnings) =
-        $validator->validate_request(
-            method => 'POST',
-            openapi_path => '/invoices',
-            parameters => {
-                body => [1, 'application/json', $body]
-            });
-
-    return error($r, HTTP_BAD_REQUEST, [], @$errors)
-        if scalar(@$errors) > 0;
-
+    my ($env, $r, $c, $body, $params) = @_;
     my @errors;
     my $inv = {};
     # lookup the required fields: eca
@@ -576,7 +545,7 @@ sub _post_invoices {
             #
             my $sth = $env->{'lsmb.db'}->prepare(
                 q|
-                    SELECT a.accno as category, a.description, t.rate, a.id
+                    SELECT a.accno as category, a.description, t.rate, a.id, t.chart_id
                       FROM account a JOIN tax t ON t.chart_id = a.id
                       WHERE a.accno = ?
                       AND coalesce(validto::timestamp, 'infinity')
@@ -648,6 +617,20 @@ sub _post_invoices {
         uniq map { $_->{part}->{id} } $inv->{lines}->@*
         );
 
+    $inv->{transdate} //= $inv->{crdate};
+    $inv->{crdate} //= $inv->{transdate};
+    if (not $inv->{transdate}) {
+        $env->{'psgix.logger'}->(
+            {
+                level => 'info',
+                message => 'No transaction date supplied; setting default' });
+        my ($now) = $env->{'lsmb.db'}->selectrow_array('SELECT NOW()::date')
+            or die $env->{'lsmb.db'}->errstr;
+
+        $inv->{crdate} =
+            $inv->{transdate} =
+            $now;
+    }
 
     # Step 2: Run the price matrix
     if (keys %part_qty) {
@@ -749,7 +732,9 @@ sub _post_invoices {
           or die $env->{'lsmb.db'}->errstr;
         $sth->execute($inv->{eca}->{id}, $inv->{transdate})
             or die $sth->errstr;
-        $inv->{taxes} = $sth->fetchall_hashref('accno');
+        while (my $ref = $sth->fetchrow_hashref('NAME_lc')) {
+            $inv->{taxes}->{$ref->{accno}} = { tax => $ref };
+        }
         die $sth->errstr
             if $sth->err;
         if (keys $inv->{taxes}->%* and keys %part_qty) {
@@ -810,24 +795,35 @@ sub _post_invoices {
                 my $pass = 0;
 
                 for my $tax (@taxes) {
-                    if ($pass != $tax->{pass}) {
+                    $env->{'psgix.logger'}->(
+                        {
+                            level => 'debug',
+                            message => "Considering tax $tax->{tax}->{accnon} for part $line->{part}->{id}" });
+                    next unless exists $part_tax{$line->{part}->{id}}->{$tax->{tax}->{accno}};
+                    $env->{'psgix.logger'}->(
+                        {
+                            level => 'debug',
+                            message => "processing tax for part ID $line->{part}->{id}" });
+                    if ($pass != $tax->{tax}->{pass}) {
                         $base += $passtax;
                         $passtax = 0;
-                        $pass = $tax->{pass};
+                        $pass = $tax->{tax}->{pass};
                     }
 
-                    my $amount = $base*$tax->{rate};
-                    $line->{taxes}->{$tax->{accno}} = {
-                        base   => $base,
-                        rate   => $tax->{rate},
+                    my $amount = $base*$tax->{tax}->{rate};
+                    $line->{taxes}->{$tax->{tax}->{accno}} = {
+                        'base-amount'   => $base,
+                        rate   => $tax->{tax}->{rate},
                         amount => $amount,
                     };
-                    $inv->{taxes}->{$tax->{accno}}->{base}   += $base;
-                    $inv->{taxes}->{$tax->{accno}}->{amount} += $amount;
+                    $inv->{taxes}->{$tax->{tax}->{accno}}->{'base-amount'}   += $base;
+                    $inv->{taxes}->{$tax->{tax}->{accno}}->{amount} += $amount;
+                    $inv->{taxes}->{$tax->{tax}->{accno}}->{tax} = $tax->{tax};
                 }
             }
         }
     }
+
     ###BUG: These amounts in don't have these names in the invoice resource!!!
     $inv->{taxes_total} =
         reduce { $a + $b->{amount} } LedgerSMB::PGNumber->new(0), values $inv->{taxes}->%*;
@@ -982,7 +978,7 @@ sub _post_invoices {
         |)
         or die $env->{'lsmb.db'}->errstr;
     for my $tax (values $inv->{taxes}->%*) {
-        $asth->execute($inv_id, undef, $tax->{tax}->{id},
+        $asth->execute($inv_id, undef, $tax->{tax}->{chart_id},
                        -$sign*$tax->{amount}, -$sign*$tax->{amount},
                        $inv->{currency}, $inv->{transdate},
                        $tax->{source}, $tax->{memo})
@@ -1005,9 +1001,9 @@ sub _post_invoices {
 
 
 get '/invoices' => \&_not_implemented;
-post '/invoices' => \&_post_invoices;
+post api '/invoices' => \&_post_invoices;
 
-get '/invoices/{id}' => \&_get_invoices_by_id;
+get api '/invoices/{id}' => \&_get_invoices_by_id;
 del '/invoices/{id}' => \&_not_implemented;
 patch '/invoices/{id}' => \&_not_implemented;
 
@@ -1049,8 +1045,9 @@ paths:
                 type: array
                 items:
                   $ref: '#/components/schemas/Invoice'
-                example:
-                  $ref: '#/components/examples/validInvoice'
+              examples:
+                validInvoices:
+                  $ref: '#/components/examples/validInvoices'
         400:
           $ref: '#/components/responses/400'
         401:
@@ -1527,6 +1524,100 @@ components:
                   type: string
                   enum: [INITIAL, SAVED, POSTED, ONHOLD, VOIDED, REVERSED, DELETED]
   examples:
+    validInvoices:
+      summary: Valid invoices (collection response)
+      description: Invoices collection response
+      value:
+        - account:
+            accno: "1200"
+            description: AR
+          currency: "USD"
+          dates:
+            created: "2022-09-01"
+            due: "2022-10-01"
+            book: "2022-10-05"
+          description:
+          eca:
+            number: "Customer 1"
+            type: "customer"
+            credit_limit:
+              total: 0
+              used: 0
+              available: 0
+            description:
+            entity:
+              control_code: C-0
+              name: Customer 1
+            id: 1
+            pay_to_name:
+          id: "1"
+          "internal-notes": "Internal notes"
+          "invoice-number": "2389434"
+          lines:
+            - delivery_date: "2022-10-27"
+              description: "A description"
+              discount: 12
+              discount_type: "%"
+              id: 1
+              item: 1
+              notes:
+              part:
+                description: Part 1
+                number: "p1"
+                onhand: "0"
+                unit: "ea"
+                weight: "0"
+              price: 56.78
+              price_fixated: false
+              qty: 1
+              serialnumber: "1234567890"
+              total: 49.97
+              unit: "lbs"
+          lines_total: 49.97
+          notes: "Notes"
+          "order-number": "order 345"
+          #TODO: Add payments here
+          #payments:
+          #  - account:
+          #      accno: "5010"
+          #    date: "2022-11-05"
+          #    description: Payment 1
+          #    amount: 20
+          #    memo: "depot"
+          #    source: "visa"
+          "po-number": "po 456"
+          "quote-number": ""
+          #TODO: Add/debug ship-to
+          #"ship-to": "ship to there"
+          "ship-via": "ship via"
+          "shipping-point": "shipping from here"
+          taxes:
+            "2150":
+              amount: 6.78
+              "base-amount": 50
+              "calculated-amount": 2.5
+              source: "Part 1"
+              memo: "tax memo"
+              tax:
+                category: "2150"
+                name: Sales Tax
+                rate: "0.05"
+          taxes_total: 6.78
+          total: 56.75
+          type: customer
+          workflow:
+            actions:
+              - approve
+              - copy_to_new
+              - del
+              - edit_and_save
+              - new_screen
+              - sales_order
+              - save_info
+              - schedule
+              - ship_to
+              - update
+            state: SAVED
     validInvoice:
       summary: Example Invoice
       description: Invoice entry
