@@ -1,5 +1,4 @@
 
-
 package LedgerSMB::Scripts::contact;
 
 =head1 NAME
@@ -15,8 +14,9 @@ This module is the UI controller for the customer, vendor, etc functions; it
 
 =cut
 
-use strict;
+use v5.36;
 use warnings;
+use Scalar::Util qw( blessed );
 
 use Feature::Compat::Try;
 
@@ -84,10 +84,9 @@ sub get_by_cc {
     $entity ||=  LedgerSMB::Entity::Person->get_by_cc($request->{control_code});
     my ($company, $person) = (undef, undef);
 
-    local $@ = undef;
-    if (eval {$entity->isa('LedgerSMB::Entity::Company')}){
+    if (blessed $entity and $entity->isa('LedgerSMB::Entity::Company')) {
         $company = $entity;
-    } elsif (eval {$entity->isa('LedgerSMB::Entity::Person')}){
+    } elsif (blessed $entity and $entity->isa('LedgerSMB::Entity::Person')) {
         $person = $entity;
     }
 
@@ -117,10 +116,9 @@ sub get {
     $entity ||= LedgerSMB::Entity::Person->get($request->{entity_id});
     my ($company, $person) = (undef, undef);
 
-    local $@ = undef;
-    if (eval {$entity->isa('LedgerSMB::Entity::Company')}){
+    if (blessed $entity and $entity->isa( 'LedgerSMB::Entity::Company')) {
         $company = $entity;
-    } elsif (eval {$entity->isa('LedgerSMB::Entity::Person')}){
+    } elsif (blessed $entity and $entity->isa('LedgerSMB::Entity::Person')) {
         $person = $entity;
     }
 
@@ -147,8 +145,9 @@ sub _main_screen {
        unshift @DIVS, 'company' if $company->{entity_id};
        unshift @DIVS, 'person' if $person->{entity_id};
        if ($person->{entity_id} && $person->{entity_class}
-                && $person->{entity_class} == EC_EMPLOYEE ){
-          shift @DIVS;
+                && $request->{entity_class} == EC_EMPLOYEE ){
+           shift @DIVS; # Person/Company
+           shift @DIVS; # Credit Accounts
           if ($request->setting->get('enable_wage_screen')) {
               unshift @DIVS, 'wage';
           }
@@ -220,7 +219,6 @@ sub _main_screen {
     }
 
     my $entity_class = $credit_act->{entity_class};
-    $entity_class ||= $company->{entity_class};
     $entity_class ||= $request->{entity_class};
     $entity_class ||= $request->{account_class};
     my @locations = LedgerSMB::Entity::Location->get_active(
@@ -393,7 +391,14 @@ sub save_employee {
     $request->{control_code} = $request->{employeenumber} if defined $request->{employeenumber};
     $request->{employeenumber} ||= $request->{control_code};
     $request->{name} = "$request->{last_name}, $request->{first_name}";
-    my $employee = LedgerSMB::Entity::Person::Employee->new(%$request);
+    my $employee = LedgerSMB::Entity::Person::Employee->new(
+        %$request,
+        dob => $request->parse_date( $request->{dob} ),
+        birthdate => $request->parse_date( $request->{birthdate} ),
+        created => $request->parse_date( $request->{created} ),
+        start_date => $request->parse_date( $request->{start_date} ),
+        end_date => $request->parse_date( $request->{end_date} ),
+        );
     $request->{target_div} = 'employee_div';
     $employee->save;
     return _main_screen($request, undef, $employee);
@@ -560,7 +565,10 @@ sub save_company {
         ($request->{control_code}) = values %$ref;
     }
     $request->{name} ||= $request->{legal_name};
-    my $company = LedgerSMB::Entity::Company->new(%$request);
+    my $company = LedgerSMB::Entity::Company->new(
+        %$request,
+        created => $request->parse_date( $request->{created} ),
+        );
     $request->{target_div} = 'credit_div';
     return _main_screen($request, $company->save);
 }
@@ -584,8 +592,10 @@ sub save_person {
                            );
         ($request->{control_code}) = values %$ref;
     }
+    my $birthdate = $request->parse_date($request->{birthdate});
     my $person = LedgerSMB::Entity::Person->new(
-              %$request
+        %$request,
+        birthdate => $birthdate
     );
     $request->{target_div} = 'credit_div';
     $person->save;
@@ -618,7 +628,23 @@ sub save_credit {
         }
     }
     if ($request->close_form){
-        my $credit = LedgerSMB::Entity::Credit_Account->new(%$request);
+        my $credit = LedgerSMB::Entity::Credit_Account->new(
+            $request->%{qw( id entity_id entity_class pay_to_name
+                            description discount_terms
+                            discount_account_id taxincluded
+                            terms meta_number business_type
+                            business_id language_code
+                            pricegroup_id curr
+                            employee_id ar_ap_account_id
+                            cash_account_id bank_account tax_ids
+                            taxform_id )},
+            discount => $request->parse_amount( $request->{discount} ),
+            creditlimit => $request->parse_amount( $request->{creditlimit} ),
+            current_debt => $request->parse_amount( $request->{current_debt} ),
+            threshold => $request->parse_amount( $request->{threshold} ),
+            startdate => $request->parse_date( $request->{startdate} ),
+            enddate => $request->parse_date( $request->{enddate} ),
+            );
         $credit = $credit->save();
         $request->{meta_number} = $credit->{meta_number};
     }
@@ -638,6 +664,19 @@ sub save_credit_new {
     return save_credit($request);
 }
 
+=item update_credit($request)
+
+Reload the drop-downs linked to the Class drop-down (customer/vendor)
+
+=cut
+
+
+sub update_credit {
+    my ($request) = @_;
+    $request->{target_div} = 'credit_div';
+    return get($request);
+}
+
 =item save_location
 
 Adds a location to the company as defined in the inherited object
@@ -651,7 +690,10 @@ sub save_location {
     if ($request->{attach_to} == 1){
        delete $request->{credit_id};
     }
-    my $location = LedgerSMB::Entity::Location->new(%$request);
+    my $location = LedgerSMB::Entity::Location->new(
+        %$request,
+        inactive_date => $request->parse_date( $request->{inactive_date} ),
+        );
     $request->{credit_id} = $credit_id;
     $location->id($request->{location_id}) if $request->{location_id};
     $location->save;
@@ -773,7 +815,10 @@ Required request variables:
 
 sub delete_bank_account{
     my ($request) = @_;
-    LedgerSMB::Entity::Bank->get($request->{id})->delete;
+    LedgerSMB::Entity::Bank->delete(
+        $request->{id},
+        $request->{entity_id}
+    );
     $request->{target_div} = 'bank_act_div';
     return get($request);
 }
@@ -1007,7 +1052,7 @@ sub save_roles {
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012 The LedgerSMB Core Team
+Copyright (C) 2012-2023 The LedgerSMB Core Team
 
 This file is licensed under the GNU General Public License version 2, or at your
 option any later version.  A copy of the license should have been included with
