@@ -33,9 +33,11 @@ sub chart_of_accounts {
 
     return $request->render_report(
         LedgerSMB::Report::COA->new(
+            formatter_options => $request->formatter_options,
             _locale => $request->{_locale},
             _uri => $request->{_uri},
-            dbh => $request->{dbh})
+            dbh => $request->{dbh}),
+        formatter_options => $request->formatter_options
         );
 }
 
@@ -105,10 +107,38 @@ sub search {
          push @{$request->{business_units}}, $request->{"business_unit_$count"}
                if $request->{"business_unit_$count"};
     }
-    #tshvr4 trying to mix in period from_month from_year interval
+
+    my @report_keys = ( 'business_units',  # created above
+                        '_uri',            # to allow sorting
+                        qw( reference accno source memo
+                            description notes
+                            from_month from_year
+                            interval
+                            is_approved
+                            is_voided
+                            category
+                            order_by
+                            old_order_by
+                            order_dir ),
+                        grep { m/^(bc_|col_)/ } keys $request->%* );
+
+    my %parsed_dates = ();
+    if ($request->{from_date}) {
+        $parsed_dates{from_date} = $request->parse_date( $request->{from_date} );
+    }
+    if ($request->{to_date}) {
+        $parsed_dates{to_date} = $request->parse_date( $request->{to_date} );
+    }
+
     return $request->render_report(
-        LedgerSMB::Report::GL->new(%$request)
-        );
+        LedgerSMB::Report::GL->new(
+            $request->%{@report_keys},
+            formatter_options => $request->formatter_options,
+            from_amount => $request->parse_amount( $request->{from_amount} ),
+            to_amount => $request->parse_amount( $request->{to_amount} ),
+            locale => $request->{_locale},
+            %parsed_dates
+        ));
 }
 
 =head2 search_purchases
@@ -126,14 +156,19 @@ sub search_purchases {
                if $request->{"business_unit_$count"};
     }
     return $request->render_report(
-        LedgerSMB::Report::Contact::Purchase->new(%$request)
-        );
+        LedgerSMB::Report::Contact::Purchase->new(
+            %$request,
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+            as_of => $request->parse_date( $request->{as_of} ),
+            formatter_options => $request->formatter_options
+        ));
 }
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2011-2018 The LedgerSMB Core Team
+Copyright (C) 2011-2023 The LedgerSMB Core Team
 
 This file is licensed under the GNU General Public License version 2, or at your
 option any later version.  A copy of the license should have been included with
