@@ -123,8 +123,10 @@ Lists the business types.  No inputs expected or used.
 sub list_business_types {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::Business_Type->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Business_Type->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item list_gifi
@@ -136,8 +138,10 @@ List the gifi entries.  No inputs expected or used.
 sub list_gifi {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::GIFI->new(%$request)
-        );
+        LedgerSMB::Report::Listings::GIFI->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item list_warehouse
@@ -149,8 +153,10 @@ List the warehouse entries.  No inputs expected or used.
 sub list_warehouse {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::Warehouse->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Warehouse->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item list_language
@@ -162,8 +168,10 @@ List language entries.  No inputs expected or used.
 sub list_language {
     my ($request) = @_;
     return $request->render_report(
-        LedgerSMB::Report::Listings::Language->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Language->new(
+            %$request,
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item list_sic
@@ -185,24 +193,21 @@ Generates a balance sheet
 
 =cut
 
-use Log::Any;
-my $logger = Log::Any->get_logger(category => 'LedgerSMB::Scripts::reports');
-
 sub generate_balance_sheet {
     my ($request) = @_;
-    $logger->debug("Stub LedgerSMB::Scripts::reports->generate_balance_sheet\n");
     my $rpt = LedgerSMB::Report::Balance_Sheet->new(
         %$request,
+        formatter_options => $request->formatter_options,
+        from_date  => $request->{from_date} ? $request->parse_date( $request->{from_date} ) : undef,
+        to_date  => $request->{to_date} ? $request->parse_date( $request->{to_date} ) : undef,
         column_path_prefix => [ 0 ]);
     $rpt->run_report($request);
 
-    for my $key (qw(from_month from_year from_date to_date internal)) {
-        delete $request->{$_} for (grep { /^$key/ } keys %$request);
-    }
-
     for my $cmp_dates (@{$rpt->comparisons}) {
         my $cmp = LedgerSMB::Report::Balance_Sheet->new(
-            %$request, %$cmp_dates);
+            %$request,
+            formatter_options => $request->formatter_options,
+            %$cmp_dates);
         $cmp->run_report($request);
         $rpt->add_comparison($cmp);
     }
@@ -222,8 +227,13 @@ sub search_overpayments {
                post_date batch_class account_class);
 
     return $request->render_report(
-        LedgerSMB::Report::Listings::Overpayments->new(%$request)
-        );
+        LedgerSMB::Report::Listings::Overpayments->new(
+            %$request,
+            post_date => $request->parse_date( $request->{post_date} ),
+            from_date => $request->parse_date( $request->{from_date} ),
+            to_date => $request->parse_date( $request->{to_date} ),
+            formatter_options => $request->formatter_options
+        ));
 }
 
 =item reverse_overpayment
