@@ -236,6 +236,11 @@ sub get_dispatch_table {
         message => $request->{_locale}->text('LedgerSMB 1.11 db found.'),
         operation => $request->{_locale}->text('Rebuild/Upgrade?'),
         next_action => 'rebuild_modules' },
+      { appname => 'ledgersmb',
+        version => '1.12',
+        message => $request->{_locale}->text('LedgerSMB 1.12 db found.'),
+        operation => $request->{_locale}->text('Rebuild/Upgrade?'),
+        next_action => 'rebuild_modules' },
       { appname => 'ledgersmb',
         version => undef,
         message => $request->{_locale}->text('Unsupported LedgerSMB version detected.'),
@@ -1318,10 +1323,11 @@ sub _save_user {
     $request->{dbh}->{AutoCommit} = 0;
 
     $request->{control_code} = $request->{employeenumber};
-    local $LedgerSMB::App_State::User = {};
     my $emp = LedgerSMB::Entity::Person::Employee->new(
         %$request,
-        dob => LedgerSMB::PGDate->from_input($request->{dob})
+        dob => $request->parse_date( $request->{dob} ),
+        start_date => $request->parse_date( $request->{start_date} ),
+        end_date => $request->parse_date( $request->{end_date} ),
         );
     $emp->save;
     $request->{entity_id} = $emp->entity_id;
@@ -1444,7 +1450,6 @@ sub edit_user_roles {
         unless $request->{dbh};
     return $reauth if $reauth;
 
-    local $LedgerSMB::App_State::User = {};
     my $template = $request->{_wire}->get('ui');
     my ($user) = $request->call_procedure(
         funcname => 'admin__get_user',
@@ -1590,20 +1595,14 @@ between versions on a stable branch (typically upgrading)
 sub _rebuild_modules {
     my ($request, $entrypoint, $database) = @_;
 
-    if (not defined $database) {
-        my ($reauth, $db) = _init_db($request);
-        return $reauth if $reauth;
-
-        $database = $db;
-    }
-
     # The order is important here:
     #  New modules should be able to depend on the latest changes
     #  e.g. table definitions, etc.
 
     $request->{resubmit_action} //= $entrypoint;
     my $HTML = html_formatter_context {
-        return ! $database->apply_changes( checks => 1 );
+        return ! $database->apply_changes( checks => 1,
+                                           run_id => $request->{run_id} );
     } $request;
 
     return [ HTTP_OK,
@@ -1615,6 +1614,9 @@ sub _rebuild_modules {
     $database->upgrade_modules('LOADORDER', $LedgerSMB::VERSION)
         or die 'Upgrade failed.';
 
+    $database->run_postupgrade_hooks;
+
+    $logger->info('Completed database upgrade run ' . $database->upgrade_run_id);
     return;
 }
 
@@ -1624,10 +1626,14 @@ sub rebuild_modules {
     if (my $csrf = $request->verify_csrf) {
         return $csrf;
     }
-    if (my $rv = _rebuild_modules($request, 'rebuild_modules')) {
+
+    my ($reauth, $db) = _init_db($request);
+    return $reauth if $reauth;
+
+    if (my $rv = _rebuild_modules($request, 'rebuild_modules', $db)) {
         return $rv;
     }
-    return complete($request);
+    return _complete($request, $db);
 }
 
 =item complete
@@ -1637,20 +1643,40 @@ Gets the statistics info and shows the complete screen.
 =cut
 
 sub _complete {
-    my ($request) = @_;
-    if (my $csrf = $request->verify_csrf) {
-        return $csrf;
-    }
-    my ($reauth, $database) = _init_db($request);
-    return $reauth if $reauth;
+    my ($request, $database) = @_;
 
-    my $temp = $database->loader_log_filename();
-    $request->{lsmb_info} = $database->stats();
+    # the workflow state machine dispatches here (without database)
+    if (not defined $database) {
+        my ($reauth, $db) = _init_db($request);
+        return $reauth if $reauth;
+
+        $database = $db;
+    }
+
+    if ($database->upgrade_run_id) {
+        $logger->debug('Collecting run information for upgrade run '
+                       . $database->upgrade_run_id);
+        $request->{run_id}   = $database->upgrade_run_id;
+        $request->{run_info} =
+            $database->list_changes( run_id => $database->upgrade_run_id );
+        $logger->debug('Collected ' . scalar($request->{run_info})
+                       . ' upgrade run items');
+    }
+    else {
+        $request->{lsmb_info} = $database->stats();
+    }
     my $template = $request->{_wire}->get('ui');
     return $template->render($request, 'setup/complete', $request);
 }
 
-sub complete { return _complete(@_) };
+sub complete {
+    my ($request) = @_;
+    if (my $csrf = $request->verify_csrf) {
+        return $csrf;
+    }
+
+    return _complete($request);
+};
 
 =item system_info
 
@@ -1681,6 +1707,30 @@ sub system_info {
         ->render($request, 'setup/system_info', $request);
 }
 
+=item db_patches_log
+
+Lists all database schema patches that have been applied.
+
+=cut
+
+sub db_patches_log {
+    my ($request) = @_;
+    if (my $csrf = $request->verify_csrf) {
+        return $csrf;
+    }
+
+    my ($reauth, $db) = _init_db($request);
+    return $reauth if $reauth;
+
+    $logger->debug('Collecting run information for all db patches');
+    $request->{run_info} = $db->list_changes;
+    $logger->debug('Collected ' . scalar($request->{run_info})
+                   . ' upgrade run items');
+
+    my $template = $request->{_wire}->get('ui');
+    return $template->render($request, 'setup/db-patches-log', $request);
+};
+
 
 =back
 
