@@ -112,14 +112,14 @@ sub save_info {
 }
 
 sub approve {
-    $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
-    if ($form->{workflow_id}) {
-        my $wf = $form->{_wire}->get('workflows')->fetch_workflow(
-            'GL', $form->{workflow_id}
-            );
-        $wf->context->param( transdate => $form->{transdate} );
-        $wf->execute_action( $form->{__action} );
-    }
+    my $wf = $form->{_wire}->get('workflows')->fetch_workflow(
+        'GL', $form->{workflow_id}
+        );
+    die q|No workflow found to approve| unless $wf;
+
+    $wf->context->param( transdate => $form->{transdate} );
+    $wf->execute_action( $form->{__action} );
+
     if ($form->{callback}){
         print "Location: $form->{callback}\n";
         print "Status: 302 Found\n\n";
@@ -525,9 +525,9 @@ sub display_row {
         }
         else {
             $form->{"debit_$i"} =
-                LedgerSMB::PGNumber->from_input($form->{"debit_$i"});
+                $form->parse_amount( \%myconfig,$form->{"debit_$i"});
             $form->{"credit_$i"} =
-                LedgerSMB::PGNumber->from_input($form->{"credit_$i"});
+                $form->parse_amount( \%myconfig,$form->{"credit_$i"});
             $form->{totaldebit}  += ($form->{"debit_$i"} // 0);
             $form->{totalcredit} += ($form->{"credit_$i"} // 0);
 
@@ -573,12 +573,6 @@ sub edit {
 
     $form->all_business_units($form->{transdate}, undef, 'GL');
 
-    # readonly
-    if ( !$form->{readonly} ) {
-        $form->{readonly} = 1
-            if ($myconfig{acs}
-                and $myconfig{acs} =~ /General Ledger--Add Transaction/);
-    }
     $form->{title} = "Edit";
     if ($form->{department_id}) {
          $form->{department}=$form->{departmentdesc}."--".$form->{department_id};
@@ -630,7 +624,7 @@ sub update {
     my $min_lines = $form->get_setting('min_empty');
     $form->open_form unless $form->check_form;
 
-    $form->{transdate} = LedgerSMB::PGDate->from_input($form->{transdate})->to_output();
+    $form->{transdate} = $form->parse_date( \%myconfig, $form->{transdate} )->to_output();
     if ( $form->{transdate} ne $form->{oldtransdate} ) {
         $form->{oldtransdate} = $form->{transdate};
     }
@@ -745,16 +739,13 @@ sub post {
 }
 
 sub del {
-    $form->error($locale->text('Cannot delete posted transaction'))
-       if ($form->{approved});
-    if ($form->{workflow_id}) {
-        my $wf = $form->{_wire}->get('workflows')->fetch_workflow(
-            'GL', $form->{workflow_id}
-            );
-        $wf->context->param( transdate => $form->{transdate} );
-        $wf->execute_action( $form->{__action} );
-    }
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
+    my $wf = $form->{_wire}->get('workflows')->fetch_workflow(
+        'GL', $form->{workflow_id}
+        );
+    die 'No workflow to mark deleted' unless $wf;
+    $wf->context->param( transdate => $form->{transdate} );
+    $wf->execute_action( $form->{__action} );
+
     delete $form->{id};
     delete $form->{reference};
     new();
@@ -817,14 +808,14 @@ sub print {
         my $amount = $form->{"debit_0"} eq "" ? $form->{"credit_0"} : $form->{"debit_0"};
         my $amount_fx = $form->{"debit_fx_0"} eq "" ? $form->{"credit_fx_0"} : $form->{"debit_fx_0"};
 
-        $form->{exchange_rate} = LedgerSMB::PGNumber->from_input($amount) / LedgerSMB::PGNumber->from_input($amount_fx);
+        $form->{exchange_rate} = $form->parse_amount( \%myconfig,$amount) / $form->parse_amount( \%myconfig,$amount_fx);
         $form->{exchange_rate} = $form->format_amount( \%myconfig, $form->{exchange_rate}, LedgerSMB::Setting->new(%$form)->get('decimal_places') );
 
         $form->{curr} = $form->{"curr_0"};;
 
         $form->{amount} = $form->{totaldebit};
         my $fmt = LedgerSMB::Num2text->new($form->{_locale});
-        $form->{text_amount} = $fmt->num2text(LedgerSMB::PGNumber->from_input($form->{amount}));
+        $form->{text_amount} = $fmt->num2text($form->parse_amount( \%myconfig,$form->{amount}));
     } else {
         # render the code--description for all business unit instead of id
         for my $drow (@displayrows) {
@@ -863,6 +854,7 @@ sub print {
         path => 'DB',
         locale => $locale,
         output_options => \%output_options,
+        formatter_options => $form->formatter_options,
         format_plugin => $form->{_wire}->get( 'output_formatter' )->get( 'HTML' ),
     );
     $template->render(
