@@ -132,11 +132,10 @@ sub _calc_taxes {
 }
 
 sub approve {
-    $form->update_invnumber;
-    $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
-
     my $wf = $form->{_wire}->get('workflows')
         ->fetch_workflow( 'AR/AP', $form->{workflow_id} );
+    die 'No workflow found to approve' unless $wf;
+
     $wf->execute_action( 'approve' );
     my $query =
         ($form->{vc} eq 'customer')
@@ -625,11 +624,7 @@ sub new_item {
 
 <h4 class=error>| . $locale->text('Item not on file!') . qq|</h4>|;
 
-    if ( $myconfig{acs} !~
-        /(Goods \& Services--Add Part|Goods \& Services--Add Service)/ )
-    {
-
-        print qq|
+    print qq|
 <h4>| . $locale->text('What type of item is this?') . qq|</h4>
 
 <form method="post" data-dojo-type="lsmb/Form" action="ic.pl">
@@ -648,16 +643,15 @@ sub new_item {
 <input type=hidden name=action value=add>
 |;
 
-        $form->hide_form(qw(previousform rowcount path login sessionid));
+    $form->hide_form(qw(previousform rowcount path login sessionid));
 
-        print qq|
+    print qq|
 <p>
 <button data-dojo-type="dijit/form/Button" class="submit" type="submit" name="__action" value="continue">|
           . $locale->text('Continue')
           . qq|</button>
 </form>
 |;
-    }
 
     print qq|
 </body>
@@ -719,7 +713,7 @@ sub display_form {
 
     &{$subroutine}($numrows) if $numrows;
 
-    $form->hide_form(qw|locationid|);
+    $form->hide_form(qw|shiptolocationid|);
 
     &form_footer;
     $form->finalize_request unless $want_return;
@@ -1352,11 +1346,11 @@ sub print_form {
         }
     }
     my @vars =
-      qw(name address1 address2 city state zipcode country contact phone fax email);
+      qw(name attn address1 address2 city state zipcode country contact phone fax email);
 
     $shipto = 0;
     # if there is no shipto fill it in from billto
-    $form->get_shipto($form->{locationid}) if $form->{locationid};
+    $form->get_shipto($form->{shiptolocationid}) if $form->{shiptolocationid};
     foreach my $item (@vars) {
         if ($form->{"shipto$item"} ) {
             $shipto = 1;
@@ -1390,7 +1384,8 @@ sub print_form {
 
     # before we format replace <%var%>
     for (qw(notes intnotes message)) {
-        $form->{$_} =~ s/<%(.*?)%>/$form->{$1}/g;
+        $form->{$_} =~ s/<%(.*?)%>/$form->{$1}/g
+            if $form->{$_};
     }
 
 
@@ -1433,6 +1428,7 @@ sub print_form {
                 language => $form->{language_code},
                 output_options => \%output_options,
                 filename => $form->{formname} . "-" . $form->{"${inv}number"},
+                formatter_options => $form->formatter_options,
                 format_plugin   =>
                    $form->{_wire}->get( 'output_formatter' )->get( uc($form->{format} ) ),
             );
@@ -1457,7 +1453,7 @@ sub print_form {
 
     paid subtotal total
 
-    shipto shiptoname shiptoaddress1 shiptoaddress2 shiptocity shiptostate
+    shipto shiptoname shiptoattn shiptoaddress1 shiptoaddress2 shiptocity shiptostate
     shiptozipcode shiptocountry shiptocontact shiptophone shiptoemail
                        ))};
         my $body = $template->{output};
@@ -1542,6 +1538,9 @@ sub print_form {
         dbh => $form->{dbh},
         path => 'DB',
         language => $form->{language_code},
+        #@@@TODO the formatter options need to be based
+        # on the recipient's preferences, not on the current user!
+        formatter_options => $form->formatter_options(),
         output_options => \%output_options,
         filename => $form->{formname} . "-" . $form->{"${inv}number"},
         format_plugin   =>
@@ -1619,6 +1618,12 @@ sub ship_to {
     $form->header;
 
 
+    for (qw| address1_ address2_ address3_ city_ state_ zipcode_ country_ type_ contact_ description_|) {
+        delete $form->{"shipto${_}new"};
+    }
+    my $country=&construct_countrys_types("country");
+    my $contacttype=&construct_countrys_types("type");
+
     print qq|
                <body class="lsmb">
 
@@ -1643,60 +1648,62 @@ sub ship_to {
             <table  cellspacing="0" cellpadding="0" border="0">
                   <tr>
                   <td valign="top">
-                             <table width=70% >
+                             <table style="margin-top:1em">
+                             <caption><b>| . $locale->text('Shipping Address') . qq|</b></caption>
 
-                             <tr class=listheading> |
-                                         . qq|<th class=listheading width=1% >
-                                  |
-                                        .    $locale->text(' ')
-                                         . qq|</th>
-                                   <th class=listheading width=5%>|
-                                  .     $locale->text('Add line1')
+                             <tr class=listheading>
+                                <th class=listheading width=1% rowspan=2>&nbsp;</th>
+                                <th class=listheading colspan=3 nowrap>|
+                                . $locale->text('Address')
+                                . qq|</th>
+                                   <th class=listheading rowspan=2 width=5% nowrap>|
+                                  .     $locale->text('City')
                                   . qq|</th>
-                                   <th class=listheading width=5%>|
-                                  .    $locale->text('Add line2')
-                                  . qq|</th>
-                                   <th class=listheading width=1% >
-                                  |
-                                  .     $locale->text('Add line3 ')
-                                        . qq|</th>
-                                   <th class=listheading width=5%>|
-                                  .     $locale->text('city')
-                                  . qq|</th>
-                                   <th class=listheading width=5%>|
+                                   <th class=listheading rowspan=2 width=5% nowrap>|
                                   .    $locale->text('State')
                                   . qq|</th>
-                                   <th class=listheading width=5%>|
-                                  .     $locale->text('Zip Code')
+                                   <th class=listheading rowspan=2 width=5% nowrap>|
+                                  .     $locale->text('Zipcode')
                                   . qq|</th>
-                                   <th class=listheading width=5%>|
+                                   <th class=listheading rowspan=2 width=5% nowrap>|
                                   .     $locale->text('Country')
                                   . qq|
+                             </tr>
+                             <tr class=listheading>
+                                   <th class=listheading width=5% nowrap>|
+                                  .     $locale->text('Line 1')
+                                  . qq|</th>
+                                   <th class=listheading width=5% nowrap>|
+                                  .    $locale->text('Line 2')
+                                  . qq|</th>
+                                   <th class=listheading width=1% nowrap>
+                                  |
+                                  .     $locale->text('Line 3')
+                                        . qq|</th>
                            </tr>
                         |;
 
-                           my $i;
 
-                           for($i=1;$i<=$form->{totallocations};$i++)
+                           for ($i=1;$i<=$form->{totallocations};$i++)
                            {
                                my $checked = '';
                                $checked = 'CHECKED="CHECKED"'
-                                   if ($form->{locationid}
-                                       and ($form->{locationid} == $form->{"shiptolocationid_$i"}
-                                            or $form->{locationid} == $form->{"locationid_$i"}));
+                                   if ($form->{shiptolocationid}
+                                       and ($form->{shiptolocationid} == $form->{"shiptolocationid_$i"}
+                                            or $form->{shiptolocationid} == $form->{"locationid_$i"}));
 
                                 print qq|
                            <tr>
 
                               <td><input type=radio data-dojo-type="dijit/form/RadioButton" name="shiptoradio" id="shiptoradio_$i" value="$i"  $checked >
                               <input name="shiptolocationid_$i" id="shiptolocationid_$i" type="hidden" value="$form->{"shiptolocationid_$i"}" readonly></td>
-                              <td>$form->{"shiptoaddress1_$i"}</td>
-                              <td>$form->{"shiptoaddress2_$i"}</td>
-                              <td>$form->{"shiptoaddress3_$i"}</td>
-                              <td>$form->{"shiptocity_$i"}</td>
-                              <td>$form->{"shiptostate_$i"}</td>
-                              <td>$form->{"shiptozipcode_$i"}</td>
-                              <td>$form->{"shiptocountry_$i"}</td>
+                              <td nowrap>$form->{"shiptoaddress1_$i"}</td>
+                              <td nowrap>$form->{"shiptoaddress2_$i"}</td>
+                              <td nowrap>$form->{"shiptoaddress3_$i"}</td>
+                              <td nowrap>$form->{"shiptocity_$i"}</td>
+                              <td nowrap>$form->{"shiptostate_$i"}</td>
+                              <td nowrap>$form->{"shiptozipcode_$i"}</td>
+                              <td nowrap>$form->{"shiptocountry_$i"}</td>
                              <tr>
                                 |;
 
@@ -1713,42 +1720,66 @@ sub ship_to {
 
 
                                     print qq|
+                </tr>
+                <tr>
+                      <td><input type=radio data-dojo-type="dijit/form/RadioButton" name=shiptoradio id="shiptoradio-new" value="new"></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptoaddress1_new size=12 maxlength=64 value="$form->{shiptoaddress1_new}"></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptoaddress2_new size=12 maxlength=64 value="$form->{shiptoaddress2_new}"></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptoaddress3_new size=12 maxlength=64 value="$form->{shiptoaddress3_new}"></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptocity_new size=8 maxlength=32 value="$form->{shiptocity_new}"></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptostate_new size=10 maxlength=32 value="$form->{shiptostate_new}"></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptozipcode_new size=8 maxlength=10 value="$form->{shiptozipcode_new}"></td>
+                      <td><select data-dojo-type="dijit/form/Select" id="shiptocountry-new" name="shiptocountry_new">$country</select></td>
+
+                 </tr>
 
                     </table>
 
                 </td>
-                <td>&nbsp;</td>
+                </tr>
+                <tr>
                 <td valign="top" >
-                      <table width=30%>
+                      <table style="margin-top:1em">
+                        <caption><b>| . $locale->text('Shipping Attn') . qq|</b></caption>
                              <tr class=listheading>
                                  <th>&nbsp</th>
                                  <th class=listheading width="20%">|
                                     . $locale->text('Type')
-                                . qq|</th>
-                                   <th class=listheading width="35%">|
-                                . $locale->text('Contact')
                                 . qq|</th>
                                   <th class="listheading" width="35%">|
                                 . $locale->text('Description')
                                 . qq|</th>
+                                   <th class=listheading width="35%">|
+                                . $locale->text('Contact')
+                                . qq|</th>
                             </tr>
-                           <tr></tr>
-                              |;
+                              <tr>
+                                  <td><input type="radio" data-dojo-type="dijit/form/RadioButton" name="shiptoradiocontact" id="shiptoradiocontact_current" value="" CHECKED="CHECKED"></td>
+                                  <td colspan=2 nowrap>| . $locale->text('Current Attn') . qq|</td>
+                                  <td nowrap>$form->{shiptoattn}</td>
+                             </tr>    |;
 
                            for($i=1;$i<=$form->{totalcontacts};$i++)
                            {
+                               my $checked = '';
                         print qq|
                               <tr>
-                                  <td>&nbsp</td>
-                                  <td>$form->{"shiptotype_$i"}</td>
-                                  <td>$form->{"shiptocontact_$i"}</td>
-                                  <td>$form->{"shiptodescription_$i"}</td>
+                                  <td><input type="radio" data-dojo-type="dijit/form/RadioButton" name="shiptoradiocontact" id="shiptoradiocontact_$i" value="$form->{"shiptocontact_$i"}"></td>
+                                  <td nowrap>$form->{"shiptotype_$i"}</td>
+                                  <td nowrap>$form->{"shiptodescription_$i"}</td>
+                                  <td nowrap>$form->{"shiptocontact_$i"}</td>
                              </tr>    |;
 
                               }
                                  my $deletecontacts=$i;
 
                              print qq|
+                   <tr>
+                      <td><input type=radio data-dojo-type="dijit/form/RadioButton" name=shiptoradiocontact id="shiptoradiocontact-new" value="new"></td>
+                      <td><select data-dojo-type="dijit/form/Select" id="shiptotype-new" name="shiptotype_new">$contacttype</select></td>
+                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptocontact_new size=10 maxlength=100 value="$form->{shiptocontact_new}" ></td>
+                       <td><input data-dojo-type="dijit/form/TextBox" name=shiptodescription_new size=10 maxlength=100 value="$form->{shiptodescription_new}" ></td>
+                       </tr>
                       </table>
                  </td>
                </tr>
@@ -1756,16 +1787,11 @@ sub ship_to {
                 </table>
                 |;
 
-                 my $country=&construct_countrys_types("country");
-
-             my $contacttype=&construct_countrys_types("type");
-
-
               for(my $k=1;$k<$deletecontacts;$k++)
             {
-                for (qq| type_$k contact_$k description_$k |)
+                for (qw| type_ contact_ description_ |)
                 {
-                delete $form->{"shipto$_"};
+                delete $form->{"shipto$_$k"};
                 }
 
                }
@@ -1773,18 +1799,12 @@ sub ship_to {
                  delete $form->{shiptoradiocontact};
                delete $form->{shiptoradio};
 
-               for (qq| address1_new address2_new address3_new city_new state_new zipcode_new country_new type_new contact_new description_new|)
-               {
-                delete $form->{"shipto$_"};
-               }
-
-
 
               for(my $k=1;$k<$deletelocations;$k++)
               {
-                    for (qq| locationid_$k address1_$k address2_$k address3_$k city_$k state_$k zipcode_$k country_$k|)
+                    for (qw| locationid_ address1_ address2_ address3_ city_ state_ zipcode_ country_|)
                     {
-                    delete $form->{"shipto$_"};
+                    delete $form->{"shipto$_$k"};
                     }
 
               }
@@ -1792,31 +1812,6 @@ sub ship_to {
               $form->hide_form;
               print qq|
 
-              <hr valign="type" size=1 noshade >
-
-              <table valign="top">
-                <tr>
-                     Others
-                  </tr>
-                </tr>
-                      <td><input type=radio data-dojo-type="dijit/form/RadioButton" name=shiptoradio id="shiptoradio-new" value="new"></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptoaddress1_new size=12 maxlength=64 value="$form->{shiptoaddress1_new}" ></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptoaddress2_new size=12 maxlength=64 value="$form->{shiptoaddress2_new}" ></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptoaddress3_new size=12 maxlength=64 value="$form->{shiptoaddress3_new}" ></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptocity_new size=8 maxlength=32 value="$form->{shiptocity_new}" ></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptostate_new size=10 maxlength=32 value="$form->{shiptostate_new}" ></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptozipcode_new size=8 maxlength=10 value="$form->{shiptozipcode_new}" ></td>
-                      <td><select data-dojo-type="dijit/form/Select" id="shiptocountry-new" name="shiptocountry_new">$country</select></td>
-
-                      <td>&nbsp;</td>
-                      <td><input type=radio data-dojo-type="dijit/form/RadioButton" name=shiptoradiocontact value="1"></td>
-                      <td><select data-dojo-type="dijit/form/Select" id="shiptotype-new" name="shiptotype_new">$contacttype</select></td>
-                      <td><input data-dojo-type="dijit/form/TextBox" name=shiptocontact_new size=10 maxlength=100 value="$form->{shiptocontact_new}" ></td>
-                       <td><input data-dojo-type="dijit/form/TextBox" name=shiptodescription_new size=10 maxlength=100 value="$form->{shiptodescription_new}" ></td>
-
-                 </tr>
-
-
               </table>
           </td>
      </tr>
@@ -1858,7 +1853,7 @@ $locale->text('Cancel')
 
 Author...Sadashiva
 
-The list of functions would create the new location / uses existing locations , and sets the $form->{locationid}.
+The list of functions would create the new location / uses existing locations , and sets the $form->{shiptolocationid}.
 
 list_locations_contacts() would extracts all locations and sets into form parameter...
 
@@ -1868,7 +1863,7 @@ construct_countrys_types return the drop down list of the country/contact_class
 
 createlocations called by update action... calling eca__location_save and eca__save_contact
 
-setlocation_id called by continue action... just setting $form->{locationid} this is the final location id which is returned by shipto service
+setlocation_id called by continue action... just setting $form->{shiptolocationid} this is the final location id which is returned by shipto service
 
 
 
@@ -1906,7 +1901,7 @@ sub createlocations
 
     my $loc_id_index=$form->{"shiptoradio"};
 
-    my $index="locationid_".$loc_id_index;
+    my $index="shiptolocationid_".$loc_id_index;
 
     my $loc_id=$form->{$index};
 
@@ -1918,12 +1913,12 @@ sub createlocations
 
          &validatelocation;
 
-         $form->{locationid} = IIAA->createlocation($form);
+         $form->{shiptolocationid} = IIAA->createlocation($form);
 
 
     }
 
-    if($form->{shiptoradiocontact}==1)
+    if($form->{shiptoradiocontact} eq 'new')
     {
          &validatecontact;
          IIAA->createcontact($form);
@@ -1982,6 +1977,10 @@ sub setlocation_id
        my $index="shiptolocationid_".$loc_id_index;
 
        $form->{"shiptolocationid"}=$form->{$index};
+
+
+       $form->{"shiptoattn"} = $form->{shiptoradiocontact} if $form->{shiptoradiocontact};
+
 }
 
 
@@ -1996,26 +1995,33 @@ sub list_locations_contacts
 
     # get rest for the customer
     my $query = qq|
-                    WITH eca AS (select * from entity_credit_account
-                                  where id = ?
-                    )
-            select  id as shiptolocationid,line_one as shiptoaddress1,line_two as shiptoaddress2,line_three as shiptoaddress3,city as shiptocity,
-                state as shiptostate,mail_code as shiptozipcode,country as shiptocountry
-            from (
-                            select (eca__list_locations(id)).*
-                              FROM eca
-                             UNION
-                            SELECT (entity__list_locations(entity_id)).*
-                              FROM eca
-                        ) l
-                         WHERE location_class = 3;
+WITH eca AS (
+  select * from entity_credit_account
+   where id = ?
+)
+select id as shiptolocationid,
+       line_one as shiptoaddress1,
+       line_two as shiptoaddress2,
+       line_three as shiptoaddress3,
+       city as shiptocity,
+       state as shiptostate,
+       mail_code as shiptozipcode,
+       country as shiptocountry
+  from (
+    select (eca__list_locations(id)).*
+      FROM eca
+     UNION
+    SELECT (entity__list_locations(entity_id)).*
+      FROM eca
+  ) l
+ WHERE location_class = 3;
           |;
 
 
 
     my $sth = $dbh->prepare($query);
 
-    $sth->execute( $form->{customer_id} ) || $form->dberror($query);
+    $sth->execute( $form->{customer_id} // $form->{vendor_id} ) || $form->dberror($query);
 
     my $i=0;
 
@@ -2039,10 +2045,13 @@ sub list_locations_contacts
 
 
     $query = qq|
-            select c.class as shiptotype,ec.contact as shiptocontact,ec.description as shiptodescription
-            from eca_to_contact ec
-            join contact_class c on(c.id=ec.contact_class_id)
-            where ec.credit_id=?;
+select c.class as shiptotype,
+       ec.contact as shiptocontact,
+       ec.description as shiptodescription
+  from eca_to_contact ec
+  join contact_class c
+       on (c.id=ec.contact_class_id)
+ where ec.credit_id = ?;
           |;
 
 
