@@ -68,8 +68,6 @@ sub copy_to_new{
 
 sub edit_and_save {
     $form->{ARAP} = 'AP';
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
-    delete $form->{id};
     IR->post_invoice( \%myconfig, \%$form );
 
     if ($form->{workflow_id}) {
@@ -80,22 +78,6 @@ sub edit_and_save {
     edit();
 }
 
-sub approve {
-    $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
-
-    if ($form->{callback}){
-        print "Location: $form->{callback}\n";
-        print "Status: 302 Found\n\n";
-        print qq|<html><body class="lsmb">|;
-        my $url = $form->{callback};
-        print qq|If you are not redirected automatically, click <a href="$url">|
-                . qq|here</a>.</body></html>|;
-
-    } else {
-        $form->info($locale->text('Draft Posted'));
-    }
-}
-
 sub new_screen {
     my @reqprops = qw(ARAP vc dbh stylesheet batch_id script type _locale _wire);
     $oldform = $form;
@@ -137,7 +119,6 @@ sub del {
         ->fetch_workflow( 'AR/AP', $form->{workflow_id} );
     $wf->execute_action( 'del' );
 
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
     $form->info($locale->text('Draft deleted'));
 }
 
@@ -240,6 +221,8 @@ sub invoice_links {
                 # reverse paid
                 $form->{"paid_$i"} =
                   $form->{acc_trans}{$key}->[ $i - 1 ]->{amount};
+                $form->{"paid_${i}_approved"} =
+                    $form->{acc_trans}{$key}->[ $i - 1 ]->{approved};
                 $form->{"datepaid_$i"} =
                   $form->{acc_trans}{$key}->[ $i - 1 ]->{transdate};
                 $form->{"forex_$i"} = $form->{"exchangerate_$i"} =
@@ -337,7 +320,7 @@ sub form_header {
     }
     else {
         $vendor = qq|<input data-dojo-type="dijit/form/TextBox" name=vendor id=vendor value="$form->{vendor}" size=35 $roadonly>
-                 <a href="erp.pl?__action=root#contact.pl?__action=add&entity_class=1"
+                 <a href="#contact.pl?__action=add&entity_class=1"
                   id="new-contact" target="_blank">[|
                  .  $locale->text('New') . qq|]</a>|;
     }
@@ -426,7 +409,7 @@ sub form_header {
             <tr>
         <th align="right" nowrap>| .
             $locale->text('Entity Code') . qq|</th>
-        <td colspan="2" nowrap><a href="erp.pl?__action=root#contact.pl?__action=get_by_cc&control_code=$form->{entity_control_code}" target="_blank"><b>$form->{entity_control_code}</b></a></td>
+        <td colspan="2" nowrap><a href="#contact.pl?__action=get_by_cc&control_code=$form->{entity_control_code}" target="_blank"><b>$form->{entity_control_code}</b></a></td>
         <th align="right" nowrap>| .
             $locale->text('Account') . qq|</th>
         <td colspan=3>$form->{meta_number}</td>
@@ -827,12 +810,13 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" id=intnotes name=intnotes rows
 |;
 
     if ( $form->{currency} eq $form->{defaultcurrency} ) {
-        @column_index = qw(datepaid source memo paid AP_paid);
+        @column_index = qw(status datepaid source memo paid AP_paid);
     }
     else {
-        @column_index = qw(datepaid source memo paid exchangerate paidfx AP_paid);
+        @column_index = qw(status datepaid source memo paid exchangerate paidfx AP_paid);
     }
 
+    $column_data{status}       = "<th></th>";
     $column_data{datepaid}     = "<th>" . $locale->text('Date') . "</th>";
     $column_data{paid}         = "<th>" . $locale->text('Amount') . "</th>";
     $column_data{exchangerate} = "<th>" . $locale->text('Exch') . "</th>";
@@ -859,8 +843,13 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" id=intnotes name=intnotes rows
 
         $form->hide_form("cleared_$i");
 
+        my ($title, $approval_status, $icon) =
+            ($form->{approved} and $form->{"paid_${i}_approved"}) ? ('', 'approved', '')
+            : $form->{"datepaid_$i"} ? ($locale->text('Pending approval'), 'unapproved', '&#x23F2;')
+            : ('', '', '');
+        $title = qq|title="$title"| if $title;
         print qq|
-    <tr class="invoice-payment">
+        <tr class="invoice-payment $approval_status" $title>
 |;
 
         $form->{"selectAP_paid_$i"} = $form->{selectAP_paid};
@@ -896,6 +885,7 @@ qq|<input data-dojo-type="dijit/form/TextBox" name="exchangerate_$i" id="exchang
 |;
 
         $form->{"${_}_$i"} //= '' for (qw(memo source datepaid));
+        $column_data{"status_$i"} = qq|<td style="text-align:center">$icon</td>|;
         $column_data{"paid_$i"} =
 qq|<td align=center><input data-dojo-type="dijit/form/TextBox" name="paid_$i" id="paid_$i" size=11 value=$form->{"paid_$i"} $readonly></td>|;
         $column_data{"exchangerate_$i"} =
@@ -951,15 +941,9 @@ qq|<td align=center><input data-dojo-type="dijit/form/TextBox" name="memo_$i" id
     my $wf = $form->{_wire}->get( 'workflows' )->fetch_workflow( 'AR/AP', $form->{workflow_id} );
     if ( $wf and grep { $_ eq 'print' } $wf->get_current_actions ) {
         my $printops = &print_options;
-        my $formname = {
-            name => 'formname',
-            options => [
-                {text=> $locale->text('Product Receipt'), value => 'product_receipt'},
-                ]
-        };
 
         print "<br /><br />";
-        print_select($form, $formname);
+        print_select($form, $printops->{formname});
         print_select($form, $printops->{lang});
         print_select($form, $printops->{format});
         print_select($form, $printops->{media});
@@ -1066,7 +1050,7 @@ sub update {
     $form->{exchangerate} =
       $form->parse_amount( \%myconfig, $form->{exchangerate} );
 
-    $form->{$_} = LedgerSMB::PGDate->from_input($form->{$_})->to_output()
+    $form->{$_} = $form->parse_date( \%myconfig, $form->{$_} )->to_output()
        for qw(transdate duedate crdate);
 
     if ( $newname = &check_name('vendor') ) {
@@ -1261,6 +1245,7 @@ sub update {
 
 sub post_and_approve {
     post();
+    $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
 }
 
 sub post {
