@@ -76,8 +76,6 @@ sub copy_to_new{
 
 sub edit_and_save {
     $form->{ARAP} = 'AR';
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
-    delete $form->{id};
     IS->post_invoice( \%myconfig, \%$form );
 
     if ($form->{workflow_id}) {
@@ -130,7 +128,6 @@ sub del {
         ->fetch_workflow( 'AR/AP', $form->{workflow_id} );
     $wf->execute_action( 'del' );
 
-    $form->call_procedure(funcname=>'draft_delete', args => [ $form->{id} ]);
     $form->info($locale->text('Draft deleted'));
 }
 
@@ -231,6 +228,8 @@ sub invoice_links {
                     # reverse paid
                     $form->{"paid_$i"} =
                         $form->{acc_trans}{$key}->[ $i - 1 ]->{amount} * -1;
+                    $form->{"paid_${i}_approved"} =
+                        $form->{acc_trans}{$key}->[ $i - 1 ]->{approved};
                     $form->{"datepaid_$i"} =
                         $form->{acc_trans}{$key}->[ $i - 1 ]->{transdate};
                     $form->{"forex_$i"} = $form->{"exchangerate_$i"} =
@@ -337,7 +336,7 @@ sub form_header {
     else {
         $customer = qq|<input data-dojo-type="dijit/form/TextBox" id="customer" name="customer" value="$form->{customer}" size="35" $readonly>
      <a id="new-contact" target="_blank"
-        href="erp.pl?__action=root#contact.pl?__action=add&entity_class=2">[| .
+        href="#contact.pl?__action=add&entity_class=2">[| .
         $locale->text('New') . qq|]</a> |;
     }
 
@@ -464,7 +463,7 @@ sub form_header {
             <tr>
         <th align="right" nowrap>| .
             $locale->text('Entity Code') . qq|</th>
-        <td colspan="2" nowrap><a href="erp.pl?__action=root#contact.pl?__action=get_by_cc&control_code=$form->{entity_control_code}" target="_blank"><b>$form->{entity_control_code}</b></a></td>
+        <td colspan="2" nowrap><a href="#contact.pl?__action=get_by_cc&control_code=$form->{entity_control_code}" target="_blank"><b>$form->{entity_control_code}</b></a></td>
         <th align="right" nowrap>| .
             $locale->text('Account') . qq|</th>
         <td colspan=3>$form->{meta_number}</td>
@@ -488,6 +487,7 @@ sub form_header {
     $business //= '';
     $department //= '';
     $exchangerate //= '';
+    $form->get_shipto( $form->{shiptolocationid} );
     print qq|
             $business
           </table>
@@ -510,6 +510,19 @@ sub form_header {
         <th align=right nowrap><label for="shippingpoint">| . $locale->text('Shipping Point') . qq|</label></th>
         <td colspan=3><input data-dojo-type="dijit/form/TextBox" id="shippingpoint" name="shippingpoint" size="35" value="$form->{shippingpoint}" $readonly></td>
           </tr>
+          <tr>
+            <th align=right nowrap>| . $locale->text('Shipping Attn') . qq|</th>
+            <td><input name=shiptoattn id=shiptoattn data-dojo-type="dijit/form/TextBox" value="$form->{shiptoattn}"></td>
+          </tr>
+          <tr>
+            <th align=right valign=top nowrap>| . $locale->text('Shipping Address') . qq|</th>
+            <td>$form->{shiptoaddress1} <br/>
+                $form->{shiptoaddress2} <br/>
+                $form->{shiptocity}, $form->{shiptostate} <br/>
+                $form->{shiptozipcode} <br/>
+                $form->{shiptocountry}
+                </td>
+          </tr>
           <tr>
         <th align=right nowrap><label for="shipvia">| . $locale->text('Ship via') . qq|</label></th>
         <td colspan=3>
@@ -906,12 +919,13 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" id="intnotes" name="intnotes"
 |;
 
     if ( $form->{currency} eq $form->{defaultcurrency} ) {
-        @column_index = qw(datepaid source memo paid AR_paid);
+        @column_index = qw(status datepaid source memo paid AR_paid);
     }
     else {
-        @column_index = qw(datepaid source memo paid exchangerate paidfx AR_paid);
+        @column_index = qw(status datepaid source memo paid exchangerate paidfx AR_paid);
     }
 
+    $column_data{status}       = "<th></th>";
     $column_data{datepaid}     = "<th>" . $locale->text('Date') . "</th>";
     $column_data{paid}         = "<th>" . $locale->text('Amount') . "</th>";
     $column_data{exchangerate} = "<th>" . $locale->text('Exch') . "</th>";
@@ -935,8 +949,14 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" id="intnotes" name="intnotes"
 
         $form->hide_form("cleared_$i");
 
-        print qq{
-        <tr class="invoice-payment">\n};
+        my ($title, $approval_status, $icon) =
+            ($form->{approved} and $form->{"paid_${i}_approved"}) ? ('', 'approved', '')
+            : $form->{"datepaid_$i"} ? ($locale->text('Pending approval'), 'unapproved', '&#x23F2;')
+            : ('', '', '');
+        $title = qq|title="$title"| if $title;
+        print qq|
+        <tr class="invoice-payment $approval_status" $title>
+|;
 
         $form->{"selectAR_paid_$i"} = $form->{selectAR_paid};
         $form->{"selectAR_paid_$i"} =~
@@ -969,6 +989,7 @@ qq|<input data-dojo-type="dijit/form/TextBox" name="exchangerate_$i" id="exchang
 <input type="hidden" name="forex_$i" value="$form->{"forex_$i"}">
 |;
 
+        $column_data{status} = qq|<td style="text-align:center">$icon</td>|;
         $column_data{paid} =
 qq|<td align="center"><input data-dojo-type="dijit/form/TextBox" name="paid_$i" id="paid_$i" size="11" value="$form->{"paid_$i"}" $readonly></td>|;
         $column_data{exchangerate} = qq|<td align="center">$exchangerate</td>|;
@@ -1022,18 +1043,8 @@ qq|<td align="center"><input data-dojo-type="dijit/form/TextBox" name="memo_$i"
     my $wf = $form->{_wire}->get( 'workflows' )->fetch_workflow( 'AR/AP', $form->{workflow_id} );
     if ( $wf and grep { $_ eq 'print' } $wf->get_current_actions ) {
         my $printops = &print_options;
-        my $formname = {
-            name => 'formname',
-            options => [
-                {text=> $locale->text('Sales Invoice'), value => 'invoice'},
-                {text=> $locale->text('Packing List'),  value => 'packing_list'},
-                {text=> $locale->text('Envelope'),      value => 'envelope'},
-                {text=> $locale->text('Shipping Label'), value=> 'shipping_label'},
-                ]
-        };
-
         print "<br /><br />";
-        print_select($form, $formname);
+        print_select($form, $printops->{formname});
         print_select($form, $printops->{lang});
         print_select($form, $printops->{format});
         print_select($form, $printops->{media});
@@ -1140,7 +1151,7 @@ sub update {
     $form->{exchangerate} =
       $form->parse_amount( \%myconfig, $form->{exchangerate} );
 
-    $form->{$_} = LedgerSMB::PGDate->from_input($form->{$_})->to_output()
+    $form->{$_} = $form->parse_date( \%myconfig, $form->{$_} )->to_output()
        for qw(transdate duedate crdate);
 
 
@@ -1343,6 +1354,7 @@ sub update {
 
 sub post_and_approve {
     post();
+    $form->call_procedure(funcname=>'draft_approve', args => [ $form->{id} ]);
 }
 
 sub post {
