@@ -70,24 +70,13 @@ sub get_files {
 
 }
 
-sub add_cogs {
-    my ($self, $form) = @_;
-    my $dbh = $form->{dbh};
-    my $query =
-     "select cogs__add_for_ap_line(id) FROM invoice WHERE trans_id = ?";
-    my $sth = $dbh->prepare($query) || $form->dberror($query);
-    $sth->execute($form->{id}) || $form->dberror($query);
-}
-
 sub post_invoice {
     my ( $self, $myconfig, $form ) = @_;
     $form->{crdate} ||= 'now';
     delete $form->{reverse} unless $form->{reverse};
 
     $form->all_business_units;
-    if ($form->{id}){
-        delete_invoice($self, $myconfig, $form);
-    }
+
     my $dbh = $form->{dbh};
     $form->{invnumber} = $form->update_defaults( $myconfig, "vinumber", $dbh )
       if $form->should_update_defaults('invnumber');
@@ -134,27 +123,28 @@ sub post_invoice {
 
     my %updparts = ();
 
+    # check if id really exists
     if ( $form->{id} ) {
-        $form->error("Can't re-post invoice!");
+        # delete detail records
+        $query = qq|SELECT draft__delete_lines(?)|;
+        $dbh->do($query, {}, $form->{id}) || $form->dberror($query);
     }
-
-    my $uid = localtime;
-    $uid .= "$$";
-
-    if ( !$form->{id} ) {
+    else {
+        my $uid = localtime;
+        $uid .= "$$";
 
         $query = qq|
             INSERT INTO ap (invnumber, person_id, entity_credit_account)
-            VALUES ('$uid', person__get_my_entity_id(), ?)|;
+                 VALUES ('$uid', ?, ?)|;
         $sth = $dbh->prepare($query);
-        $sth->execute( $form->{vendor_id} )
-            || $form->dberror($query);
+        $sth->execute( $form->{employee_id}, $form->{vendor_id}) || $form->dberror($query);
 
         $query = qq|SELECT id FROM ap WHERE invnumber = '$uid'|;
         $sth   = $dbh->prepare($query);
         $sth->execute || $form->dberror($query);
 
         ( $form->{id} ) = $sth->fetchrow_array;
+
         $query = q|UPDATE transactions SET workflow_id = ?, reversing = ? WHERE id = ? AND workflow_id IS NULL|;
         $sth   = $dbh->prepare($query);
         $sth->execute( $form->{workflow_id}, $form->{reversing}, $form->{id} )
@@ -172,7 +162,6 @@ sub post_invoice {
     else {
         $exchangerate = "";
     }
-
     $form->{exchangerate} = $form->parse_amount( $myconfig, $form->{exchangerate} );
 
 
@@ -274,32 +263,16 @@ sub post_invoice {
 
             # save detail record in invoice table
             $query = qq|
-                INSERT INTO invoice (description)
-                     VALUES ('$uid')|;
-            $dbh->do($query) || $form->dberror($query);
-
-            $query = qq|
-                SELECT id FROM invoice
-                 WHERE description = '$uid'|;
-            ($invoice_id) = $dbh->selectrow_array($query);
-
-            $query = qq|
-                UPDATE invoice
-                   SET trans_id = ?,
-                       parts_id = ?,
-                       description = ?,
-                       qty = ?,
-                       sellprice = ?,
-                       fxsellprice = ?,
-                       discount = ?,
-                       allocated = ?,
-                       unit = ?,
-                       deliverydate = ?,
-                       serialnumber = ?,
-                                       precision = ?,
-                       notes = ?,
-                                       vendor_sku = ?
-                 WHERE id = ?|;
+                INSERT INTO invoice (
+                         trans_id, parts_id, description, qty, sellprice,
+                         fxsellprice, discount, allocated, unit,
+                         deliverydate, serialnumber, precision, notes, vendor_sku)
+                       VALUES (
+                         ?, ?, ?, ?, ?,
+                         ?, ?, ?, ?,
+                         ?, ?, ?, ?, ?)
+                RETURNING id
+                |;
             $sth = $dbh->prepare($query);
             $sth->execute(
                 $form->{id},               $form->{"id_$i"},
@@ -310,8 +283,8 @@ sub post_invoice {
                 $form->{"serialnumber_$i"},
                 $form->{"precision_$i"},   $form->{"notes_$i"},
                 $form->{"partnumber_$i"},
-                $invoice_id
             ) || $form->dberror($query);
+            ($invoice_id) = $sth->fetchrow_array();
 
             for my $cls(@{$form->{bu_class}}){
                 if ($form->{"b_unit_$cls->{id}_$i"}){
@@ -533,6 +506,7 @@ sub post_invoice {
     $form->{taxincluded} //= 0;
     $form->{taxincluded} *= 1;
 
+    delete $form->{language_code} unless $form->{language_code};
     # save AP record
     $query = qq|
         UPDATE ap
@@ -557,7 +531,8 @@ sub post_invoice {
                ponumber = ?,
                        approved = ?,
                        reverse = ?,
-               crdate = ?
+               crdate = ?,
+               shipto = ?
          WHERE id = ?|;
 
     $sth = $dbh->prepare($query);
@@ -571,6 +546,7 @@ sub post_invoice {
         $form->{currency},
         $form->{language_code}, $form->{ponumber},
         $approved,              $form->{reverse},       $form->{crdate},
+        $form->{shiptolocationid},
         $form->{id}
     ) || $form->dberror($query);
 
@@ -587,10 +563,6 @@ sub post_invoice {
         if $form->{vendor} && $form->{vendor_id};
     $form->add_shipto($form->{id});
 
-    if ($form->get_setting('separate_duties')){
-        $self->add_cogs($form);
-    }
-
     foreach my $item ( keys %updparts ) {
         $item  = $dbh->quote($item);
         $query = qq|
@@ -622,12 +594,14 @@ sub retrieve_invoice {
                        WHERE ac.trans_id = ?|);
         $tax_sth->execute($form->{id});
         my $reverse = $form->{reverse} ? -1 : 1;
+        my $taxtotal = LedgerSMB::PGNumber->new(0);
         while (my $taxref = $tax_sth->fetchrow_hashref('NAME_lc')){
               $form->db_parse_numeric(sth=>$tax_sth,hashref=>$taxref);
               $form->{manual_tax} = 1;
               my $taccno = $taxref->{accno};
               $form->{"mt_amount_$taccno"} =
                   LedgerSMB::PGNumber->new($taxref->{amount} * -1 * $reverse);
+              $taxtotal = $taxtotal + $form->{"mt_amount_$taccno"};
               $form->{"mt_rate_$taccno"}  = $taxref->{rate};
               $form->{"mt_basis_$taccno"} =
                   LedgerSMB::PGNumber->new($taxref->{tax_basis} * -1 * $reverse);
@@ -635,6 +609,7 @@ sub retrieve_invoice {
               $form->{"mt_ref_$taccno"}  = $taxref->{source};
         }
     }
+    $form->{inv_tax_total} = $taxtotal;
 
     my $setting = LedgerSMB::Setting->new(%$form);
     $form->{$_} = $setting->get($_)
@@ -651,10 +626,13 @@ sub retrieve_invoice {
                    a.notes, a.intnotes, a.curr AS currency,
                    a.entity_credit_account as vendor_id, a.language_code,
                    a.ponumber, a.crdate, a.on_hold, a.reverse, a.description,
+                   a.shipto as shiptolocationid, l.line_one, l.line_two,
+                   l.line_three, l.city, l.state, l.country_id, l.mail_code,
                    tran.workflow_id
               FROM ap a
               JOIN transactions tran USING (id)
-             WHERE id = ?|;
+            LEFT JOIN location l on a.shipto = l.id
+             WHERE a.id = ?|;
         $sth = $dbh->prepare($query);
         $sth->execute( $form->{id} ) || $form->dberror($query);
 
@@ -665,17 +643,6 @@ sub retrieve_invoice {
         }
         $sth->finish;
 
-        # get shipto
-        $query = qq|SELECT ns.*, l.* FROM new_shipto ns JOIN location l ON ns.location_id = l.id WHERE ns.trans_id = ?|;
-        $sth   = $dbh->prepare($query);
-        $sth->execute( $form->{id} ) || $form->dberror($query);
-
-        $ref = $sth->fetchrow_hashref(NAME_lc);
-        for ( keys %$ref ) {
-            $form->{$_} = $ref->{$_};
-        }
-        $sth->finish;
-
         # retrieve individual items
         $query = qq|
                SELECT i.id as invoice_id,
