@@ -51,15 +51,6 @@ use Workflow::Context;
 my $logger = Log::Any->get_logger(category => 'LedgerSMB::IS');
 
 
-sub add_cogs {
-    my ($self, $form) = @_;
-    my $dbh = $form->{dbh};
-    my $query =
-     "select cogs__add_for_ar_line(id) FROM invoice WHERE trans_id = ?";
-    my $sth = $dbh->prepare($query) || $form->dberror($query);
-    $sth->execute($form->{id}) || $form->dberror($query);
-}
-
 =over
 
 =item get_files
@@ -341,47 +332,48 @@ sub invoice_details {
 
             push( @{ $form->{linetotal} }, $form->{"linetotal_$i"} );
 
-            @taxaccounts = Tax::init_taxes(
-                $form,
-                $form->{"taxaccounts_$i"},
-                $form->{"taxaccounts"}
-            );
-
-            my $ml       = 1;
-            my @taxrates = ();
-
             $tax = 0;
+            my @taxrates = ();
+                @taxaccounts = Tax::init_taxes(
+                    $form,
+                    $form->{"taxaccounts_$i"},
+                    $form->{"taxaccounts"}
+                    );
 
-            if ( $form->{taxincluded} ) {
-                $taxamount =
-                  Tax::calculate_taxes( \@taxaccounts, $form, $linetotal, 1 );
-                $taxbase = ( $linetotal - $taxamount );
-                $tax += Tax::extract_taxes( \@taxaccounts, $form, $linetotal );
-            }
-            else {
-                $taxamount =
-                  Tax::calculate_taxes( \@taxaccounts, $form, $linetotal, 0 );
-                $tax += Tax::apply_taxes( \@taxaccounts, $form, $linetotal );
-            }
+                my $ml       = 1;
 
-            foreach my $item (@taxaccounts) {
-                push @taxrates, 100 * $item->rate;
-                if (defined $form->{"mt_amount_" . $item->account}){
-                    $taxaccounts{ $item->account } +=
-                        $form->{"mt_amount_" . $item->account};
-                    $taxbase{ $item->account } +=
-                        $form->{"mt_basis_" . $item->account};
-                    next;
-                }
-                $taxaccounts{ $item->account } += $item->value;
+            if (not $form->{manual_tax}) {
                 if ( $form->{taxincluded} ) {
-                    $taxbase{ $item->account } += $taxbase;
+                    $taxamount =
+                        Tax::calculate_taxes( \@taxaccounts, $form, $linetotal, 1 );
+                    $taxbase = ( $linetotal - $taxamount );
+                    $tax += Tax::extract_taxes( \@taxaccounts, $form, $linetotal );
                 }
                 else {
-                    $taxbase{ $item->account } += $linetotal;
+                    $taxamount =
+                        Tax::calculate_taxes( \@taxaccounts, $form, $linetotal, 0 );
+                    $tax += Tax::apply_taxes( \@taxaccounts, $form, $linetotal );
                 }
             }
 
+                foreach my $item (@taxaccounts) {
+                    push @taxrates, 100 * $item->rate;
+                    if (defined $form->{"mt_amount_" . $item->account}){
+                        $taxaccounts{ $item->account } +=
+                            $form->{"mt_amount_" . $item->account};
+                        $taxbase{ $item->account } +=
+                            $form->{"mt_basis_" . $item->account};
+                        next;
+                    }
+                    $taxaccounts{ $item->account } += $item->value;
+                    if ( $form->{taxincluded} ) {
+                        $taxbase{ $item->account } += $taxbase;
+                    }
+                    else {
+                        $taxbase{ $item->account } += $linetotal;
+                    }
+                }
+
             push(
                 @{ $form->{lineitems} },
                 {
@@ -514,43 +506,95 @@ sub invoice_details {
         }
     }
 
-    $tax = 0;
-    foreach my $item ( sort keys %taxaccounts ) {
-        if ( $form->round_amount( $taxaccounts{$item}, 2 ) ) {
-            $tax += $taxamount = $form->round_amount( $taxaccounts{$item}, 2 );
+    if (not $form->{manual_tax}) {
+        $tax = 0;
+        foreach my $item ( sort keys %taxaccounts ) {
+            if ( $form->round_amount( $taxaccounts{$item}, 2 ) ) {
+                $tax += $taxamount = $form->round_amount( $taxaccounts{$item}, 2 );
 
-            push(
-                @{ $form->{taxbaseinclusive} },
-                $form->{"${item}_taxbaseinclusive"} =
-                  $form->format_amount( $myconfig, $taxbase{$item} + $tax, 2 )
-            );
+                push(
+                    @{ $form->{taxbaseinclusive} },
+                    $form->{"${item}_taxbaseinclusive"} =
+                    $form->format_amount( $myconfig, $taxbase{$item} + $tax, 2 )
+                    );
 
-            push(
-                @{ $form->{taxbase} },
-                $form->{"${item}_taxbase"} =
-                  $form->format_amount( $myconfig, $taxbase{$item}, 2 )
-            );
-            push(
-                @{ $form->{taxsummary} },
-                $form->format_amount( $myconfig, $taxbase{$item} + $taxamount, 2 )
-            );
+                push(
+                    @{ $form->{taxbase} },
+                    $form->{"${item}_taxbase"} =
+                    $form->format_amount( $myconfig, $taxbase{$item}, 2 )
+                    );
+                push(
+                    @{ $form->{taxsummary} },
+                    $form->format_amount( $myconfig, $taxbase{$item} + $taxamount, 2 )
+                    );
 
-            push(
-                @{ $form->{tax} },
-                $form->{"${item}_tax"} =
-                  $form->format_amount( $myconfig, $taxamount, 2 )
-            );
+                push(
+                    @{ $form->{tax} },
+                    $form->{"${item}_tax"} =
+                    $form->format_amount( $myconfig, $taxamount, 2 )
+                    );
 
-            push( @{ $form->{taxdescription} },
-                $form->{_accno_descriptions}->{$item} );
+                push( @{ $form->{taxdescription} },
+                      $form->{_accno_descriptions}->{$item} );
 
-            $form->{"${item}_taxrate"} =
-              $form->format_amount( $myconfig, $form->{"${item}_rate"} * 100 );
-            push( @{ $form->{taxrate} },   $form->{"${item}_taxrate"} );
-            push( @{ $form->{taxnumber} }, $form->{"${item}_taxnumber"} );
+                $form->{"${item}_taxrate"} =
+                    $form->format_amount( $myconfig, $form->{"${item}_rate"} * 100 );
+                push( @{ $form->{taxrate} },   $form->{"${item}_taxrate"} );
+                push( @{ $form->{taxnumber} }, $form->{"${item}_taxnumber"} );
+            }
         }
     }
+    else {
+        $tax = 0;
+        my $query = <<~'SQL';
+           select accno, a.description, taxnumber, te.rate*100 as rate,
+                  tax_basis, amount_tc as amount
+             from acc_trans acc
+                  join tax_extended te
+                       on acc.entry_id = te.entry_id
+                  join account a
+                       on acc.chart_id = a.id
+                  join tax
+                       on a.id = tax.chart_id
+            where trans_id = ?
+           SQL
+        my $sth = $dbh->prepare( $query )
+            or die $form->dberror( $query );
 
+        $sth->execute( $form->{id} )
+            or die $form->dberror( $query );
+
+        while ( my $ref = $sth->fetchrow_hashref( 'NAME_lc' ) ) {
+            if ( my $taxamount = $form->round_amount( $ref->{amount}, 2 ) ) {
+                $tax += $taxamount;
+                push(
+                    @{ $form->{taxbase} },
+                    $form->{"$ref->{accno}_taxbase"} =
+                    $form->format_amount( $myconfig, $ref->{tax_basis}, 2 )
+                    );
+
+                push(
+                    @{ $form->{taxsummary} },
+                    $form->format_amount( $myconfig, $ref->{tax_basis} + $taxamount, 2 )
+                    );
+
+                push(
+                    @{ $form->{tax} },
+                    $form->{"$ref->{accno}_tax"} =
+                    $form->format_amount( $myconfig, $taxamount, 2 )
+                    );
+
+                push( @{ $form->{taxdescription} }, $ref->{description} );
+
+                push( @{ $form->{taxrate} },
+                      $form->{"$ref->{accno}_taxrate"} =
+                      $form->format_amount( $myconfig, $ref->{rate} )
+                    );
+
+                push( @{ $form->{taxnumber} }, $ref->{taxnumber} );
+            }
+        }
+    }
     # adjust taxes for lineitems
     my $total = 0;
     for ( @{ $form->{lineitems} } ) {
@@ -714,10 +758,6 @@ sub post_invoice {
 
     $form->{acc_trans} = ();
 
-    if ($form->{id}){
-        delete_invoice($self, $myconfig, $form);
-    }
-
     ( $null, $form->{employee_id} ) = split /--/, $form->{employee};
     unless ( $form->{employee_id} ) {
         ( $form->{employee}, $form->{employee_id} ) = $form->get_employee;
@@ -738,14 +778,15 @@ sub post_invoice {
     my $pth = $dbh->prepare($query) || $form->dberror($query);
     $form->{is_return} ||= 0;
 
+    # check if id really exists
     if ( $form->{id} ) {
-        $form->error("Can't re-post invoices.");
+        # delete detail records
+        $query = qq|SELECT draft__delete_lines(?)|;
+        $dbh->do($query, {}, $form->{id}) || $form->dberror($query);
     }
-
-    my $uid = localtime;
-    $uid .= "$$";
-
-    if ( !$form->{id} ) {
+    else {
+        my $uid = localtime;
+        $uid .= "$$";
 
         $query = qq|
             INSERT INTO ar (invnumber, person_id, entity_credit_account)
@@ -768,7 +809,9 @@ sub post_invoice {
     if ( $form->{currency} eq $form->{defaultcurrency} ) {
         $form->{exchangerate} = 1;
     }
-
+    else {
+        $exchangerate = "";
+    }
     $form->{exchangerate} = $form->parse_amount( $myconfig, $form->{exchangerate} );
 
      my $return_cid = 0;
@@ -928,38 +971,22 @@ sub post_invoice {
                     ); # unless $form->{shipped};
             }
             # save detail record in invoice table
-            $query = qq|
-                INSERT INTO invoice (description)
-                     VALUES ('$uid')|;
-
-            $dbh->do($query) || $form->dberror($query);
-
-            $query = qq|
-                SELECT id FROM invoice
-                WHERE description = '$uid'|;
-            ($invoice_id) = $dbh->selectrow_array($query);
-
             unless ( $form->{"deliverydate_$i"} ) {
                 undef $form->{"deliverydate_$i"};
             }
             $query = qq|
-                UPDATE invoice
-                   SET trans_id = ?,
-                       parts_id = ?,
-                       description = ?,
-                       qty = ?,
-                       sellprice = ?,
-                                       precision = ?,
-                       fxsellprice = ?,
-                       discount = ?,
-                       allocated = ?,
-                       unit = ?,
-                       deliverydate = ?,
-                       serialnumber = ?,
-                       notes = ?
-                      WHERE id = ?|;
+                INSERT INTO invoice (
+                         trans_id, parts_id, description, qty, sellprice,
+                         precision, fxsellprice, discount, allocated, unit,
+                         deliverydate, serialnumber, notes)
+                       VALUES (
+                         ?, ?, ?, ?, ?,
+                         ?, ?, ?, ?, ?,
+                         ?, ?, ?)
+                RETURNING id
+                |;
 
-            $sth = $dbh->prepare($query);
+            $sth = $dbh->prepare($query) or $form->dberror($query);
             $sth->execute(
                 $form->{id},               $form->{"id_$i"},
                 $form->{"description_$i"}, $form->{"qty_$i"},
@@ -968,8 +995,8 @@ sub post_invoice {
                 $allocated,                $form->{"unit_$i"},
                 $form->{"deliverydate_$i"},
                 $form->{"serialnumber_$i"}, $form->{"notes_$i"},
-                $invoice_id
-            ) || $form->dberror($query);
+                ) || $form->dberror($query);
+            ($invoice_id) = $sth->fetchrow_array();
 
             if ($form->{batch_id}){
                 $sth = $dbh->prepare(
@@ -1192,10 +1219,12 @@ sub post_invoice {
                language_code = ?,
                ponumber = ?,
                        approved = ?,
-               crdate = ?,
-                       reverse = ?,
+                       crdate = ?,
+                              reverse = ?,
                        is_return = ?,
-                       setting_sequence = ?
+                       setting_sequence = ?,
+               shipto = ?,
+               shipto_attn = ?
          WHERE id = ?
              |;
     $sth = $dbh->prepare($query);
@@ -1215,6 +1244,7 @@ sub post_invoice {
         $form->{language_code}, $form->{ponumber}, $approved,
         $form->{crdate} || 'today', $form->{reverse},
         $form->{is_return},     $form->{setting_sequence},
+        $form->{shiptolocationid}, $form->{shiptoattn},
         $form->{id}
     ) || $form->dberror($query);
 
@@ -1226,10 +1256,6 @@ sub post_invoice {
     # save printed, emailed
     $form->save_status($dbh);
 
-    if ($form->get_setting('separate_duties')){
-        $self->add_cogs($form);
-    }
-
     return 1;
 }
 
@@ -1258,11 +1284,14 @@ sub retrieve_invoice {
                       a.reverse, a.entity_credit_account as customer_id,
                       a.language_code, a.ponumber, a.crdate,
                       a.on_hold, a.description, a.setting_sequence,
+                      a.shipto as shiptolocationid, l.line_one, l.line_two,
+                      l.line_three, l.city, l.state, l.country_id, l.mail_code,
                       tran.workflow_id
                  FROM ar a
                  JOIN transactions tran USING (id)
             LEFT JOIN entity_employee em ON (em.entity_id = a.person_id)
             LEFT JOIN entity e ON e.id = em.entity_id
+            LEFT JOIN location l on a.shipto = l.id
                 WHERE a.id = ?|;
 
         $sth = $dbh->prepare($query);
@@ -1283,27 +1312,18 @@ sub retrieve_invoice {
                        WHERE ac.trans_id = ?|);
         $tax_sth->execute($form->{id});
         my $reverse = $form->{reverse} ? -1 : 1;
+        my $taxtotal = LedgerSMB::PGNumber->new(0);
         while (my $taxref = $tax_sth->fetchrow_hashref('NAME_lc')){
               $form->{manual_tax} = 1;
               my $taccno = $taxref->{accno};
               $form->{"mt_amount_$taccno"} = $taxref->{amount} * $reverse;
+              $taxtotal = $taxtotal + $form->{"mt_amount_$taccno"};
               $form->{"mt_rate_$taccno"}  = $taxref->{rate};
               $form->{"mt_basis_$taccno"} = $taxref->{tax_basis} * $reverse;
               $form->{"mt_memo_$taccno"}  = $taxref->{memo};
               $form->{"mt_ref_$taccno"}  = $taxref->{source};
         }
-
-
-        # get shipto
-        $query = qq|SELECT ns.*, l.* FROM new_shipto ns JOIN location l ON ns.location_id = l.id WHERE ns.trans_id = ?|;
-        $sth   = $dbh->prepare($query);
-        $sth->execute( $form->{id} ) || $form->dberror($query);
-
-        $ref = $sth->fetchrow_hashref(NAME_lc);
-        $ref->{locationid} = $ref->{id};
-        delete $ref->{id};
-        for ( keys %$ref ) { $form->{$_} = $ref->{$_} unless $_ eq 'id' };
-        $sth->finish;
+        $form->{inv_tax_total} = $taxtotal;
 
         # retrieve individual items
         $query = qq|
