@@ -180,10 +180,9 @@ sub save {
             $sth   = $dbh->prepare($query);
             $sth->execute( $form->{id} ) || $form->dberror($query);
 
-            $query = qq|DELETE FROM new_shipto WHERE oe_id = ?|;
+            $query = qq|DELETE FROM oe_tax WHERE oe_id = ?|;
             $sth   = $dbh->prepare($query);
             $sth->execute( $form->{id} ) || $form->dberror($query);
-
         }
         else {    # id is not in the database
             delete $form->{id};
@@ -217,14 +216,14 @@ sub save {
         $query = qq|
             INSERT INTO oe
                 (id, ordnumber, quonumber, transdate,
-                reqdate, shippingpoint, shipvia,
+                reqdate, shippingpoint, shipvia, shipto_attn,
                 notes, intnotes, curr, closed,
                 person_id, language_code, ponumber, terms,
                 quotation, oe_class_id, entity_credit_account, workflow_id)
             VALUES
-                (?, ?, ?,
-                 ?, ?, ?,
-                 ?, ?, ?, ?, ?,
+                (?, ?, ?, ?,
+                 ?, ?, ?, ?,
+                 ?, ?, ?, ?,
                  ?, ?, ?, ?,
                  ?, ?, ?, ?)|;
         @queryargs = (
@@ -232,11 +231,13 @@ sub save {
             $form->{ordnumber},     $form->{quonumber},
             $form->{transdate},     $form->{reqdate},
             $form->{shippingpoint}, $form->{shipvia},
+            $form->{shiptoattn},
             $form->{notes},         $form->{intnotes},
             $form->{currency},      $form->{closed},
             $form->{person_id},
             $form->{language_code}, $form->{ponumber},
-            $form->{terms},         $quotation, $class_id, $form->{"$form->{vc}_id"},
+            $form->{terms},         $quotation,
+            $class_id,              $form->{"$form->{vc}_id"},
             $form->{workflow_id}
         );
         $sth = $dbh->prepare($query);
@@ -255,6 +256,7 @@ sub save {
     my @taxaccounts;
     my %taxaccounts;
     my $netamount = 0;
+    my @all_taxes;
 
     my $rowcount = $form->{rowcount};
     for my $i ( 1 .. $rowcount ) {
@@ -337,6 +339,7 @@ sub save {
                     $taxbase{ $item->account }     += $taxbase;
                 }
             }
+            push @all_taxes, @taxaccounts;
 
             $netamount += $form->{"sellprice_$i"} * $form->{"qty_$i"};
 
@@ -396,6 +399,28 @@ sub save {
     $amount = $form->round_amount( $netamount + $tax, 2 );
     $netamount = $form->round_amount( $netamount, 2 );
 
+    if (@all_taxes) {
+        my (%taxes, %bases, %rates);
+        my $query = q|
+INSERT INTO oe_tax (oe_id, tax_id, basis, rate, amount)
+VALUES (?, (select id from account where accno = ?), ?, ?, ?)
+|;
+        my $sth = $dbh->prepare($query)
+            or $form->dberror($query);
+        for my $tax (@all_taxes) {
+            $taxes{ $tax->account } //= 0;
+            $taxes{ $tax->account } += $tax->value;
+            $rates{ $tax->account } = $tax->rate;
+            $bases{ $tax->account } //= 0;
+            $bases{ $tax->account } += $tax->base;
+        }
+
+        for my $tax (keys %taxes) {
+            $sth->execute( $form->{id}, $tax,
+                           $bases{$tax}, $rates{$tax}, $taxes{$tax})
+                or $form->dberror($query);
+        }
+    }
     if ( $form->{currency} eq $form->{defaultcurrency} ) {
         $form->{exchangerate} = 1;
     }
@@ -443,7 +468,8 @@ sub save {
                 person_id = ?,
                 language_code = ?,
                 ponumber = ?,
-                terms = ?
+                terms = ?,
+                shipto = ?
             WHERE id = ?|;
 
         if ( !$form->{reqdate} ) {
@@ -460,7 +486,8 @@ sub save {
             $form->{closed},        $quotation,
             $form->{employee_id},
             $form->{language_code}, $form->{ponumber},
-            $form->{terms},         $form->{id}
+            $form->{terms},         $form->{shiptolocationid},
+            $form->{id}
         );
     }
     $sth = $dbh->prepare($query) || $form->dberror($query);
@@ -524,17 +551,17 @@ sub delete {
     $sth->execute( $form->{id} ) || $form->dberror($query);
     $sth->finish;
 
-    # delete OE record
-    $query = qq|DELETE FROM oe WHERE id = ?|;
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-    $sth->finish;
-
     # delete individual entries
     $query = qq|DELETE FROM orderitems WHERE trans_id = ?|;
     $sth->finish;
 
-    $query = qq|DELETE FROM new_shipto WHERE oe_id = ?|;
+    $query = qq|DELETE FROM oe_tax WHERE oe_id = ?|;
+    $sth   = $dbh->prepare($query);
+    $sth->execute( $form->{id} ) || $form->dberror($query);
+    $sth->finish;
+
+    # delete OE record
+    $query = qq|DELETE FROM oe WHERE id = ?|;
     $sth   = $dbh->prepare($query);
     $sth->execute( $form->{id} ) || $form->dberror($query);
     $sth->finish;
@@ -577,12 +604,11 @@ sub retrieve {
                 o.amount_tc AS invtotal, o.closed, o.reqdate,
                 o.quonumber, o.language_code,
                 o.ponumber, cr.entity_class,
-                ns.location_id as locationid
+                shipto as shiptolocationid, shipto_attn as shiptoattn
             FROM oe o
             JOIN entity_credit_account cr ON (cr.id = o.entity_credit_account)
             JOIN entity vc ON (cr.entity_id = vc.id)
             LEFT JOIN person pe ON (o.person_id = pe.entity_id)
-                        LEFT JOIN new_shipto ns ON ns.oe_id = o.id
             WHERE o.id = ?|;
         $sth = $dbh->prepare($query);
         $sth->execute( $form->{id} ) || $form->dberror($query);
@@ -599,14 +625,6 @@ sub retrieve {
         for ( keys %$ref ) { $form->{$_} = $ref->{$_} }
         $sth->finish;
 
-        $query = qq|SELECT * FROM new_shipto WHERE oe_id = ?|;
-        $sth   = $dbh->prepare($query);
-        $sth->execute( $form->{id} ) || $form->dberror($query);
-
-        $ref = $sth->fetchrow_hashref('NAME_lc');
-        for ( keys %$ref ) { $form->{$_} = $ref->{$_} unless ( $_ eq "id") }
-        $sth->finish;
-
         # get printed, emailed
         $query = qq|
             SELECT s.printed, s.emailed, s.formname
@@ -924,12 +942,12 @@ sub order_details {
                 @{ $form->{ship} },
                 $form->format_amount( $myconfig, $form->{"ship_$i"} )
             );
-            push( @{ $form->{unit} },         qq|$form->{"unit_$i"}| );
-            push( @{ $form->{bin} },          qq|$form->{"bin_$i"}| );
-            push( @{ $form->{serialnumber} }, qq|$form->{"serialnumber_$i"}| );
-            push( @{ $form->{requiredate} },  qq|$form->{"reqdate_$i"}| );
+            push( @{ $form->{unit} },         $form->{"unit_$i"} // '' );
+            push( @{ $form->{bin} },          $form->{"bin_$i"} // '' );
+            push( @{ $form->{serialnumber} }, $form->{"serialnumber_$i"} // '' );
+            push( @{ $form->{requiredate} },  $form->{"reqdate_$i"} // '' );
             push( @{ $form->{projectnumber} },
-                qq|$form->{"projectnumber_$i"}| );
+                  $form->{"projectnumber_$i"} );
 
             push( @{ $form->{sellprice} }, $form->{"sellprice_$i"} );
 
