@@ -14,7 +14,6 @@ DROP TYPE IF EXISTS company_entity CASCADE;
 
 CREATE TYPE company_entity AS(
   entity_id int,
-  entity_class int,
   legal_name text,
   tax_id text,
   sales_tax_id text,
@@ -26,6 +25,11 @@ CREATE TYPE company_entity AS(
 
 DROP TYPE IF EXISTS eca__pricematrix CASCADE;
 
+COMMENT ON TYPE company_entity IS
+  $$ Return type to query companies, combining data from the 'entity'
+  and 'company' tables.
+  $$;
+
 CREATE TYPE eca__pricematrix AS (
   parts_id int,
   int_partnumber text,
@@ -350,20 +354,17 @@ RETURN QUERY EXECUTE $sql$
                    OR state ILIKE '%' || $7 || '%')
               AND ($8 IS NULL
                    OR mail_code ILIKE $8 || '%')
-              AND ($9 IS NULL
-                   OR EXISTS (select 1 from country
-                               where name ilike '%' || $9 || '%'
-                                  or short_name ilike '%' || $9 || '%'))
-                       )
+   )
    SELECT e.id, e.control_code, ec.id, ec.meta_number::text,
           ec.description, ec.entity_class,
           c.legal_name, c.sic_code::text, b.description , ec.curr::text
      FROM entity e
      JOIN entities_matching_name c ON c.entity_id = e.id
+     JOIN country AS entity_country ON (entity_country.id = e.country_id)
 LEFT JOIN entity_credit_account ec ON (ec.entity_id = e.id)
 LEFT JOIN business b ON (ec.business_id = b.id)
     WHERE ($1 is null
-           OR coalesce(ec.entity_class, e.entity_class) = $1)
+           OR ec.entity_class = $1)
           AND ($14 IS NULL
                OR e.control_code like $14 || '%')
           AND (($3 IS NULL AND $2 IS NULL)
@@ -373,9 +374,8 @@ LEFT JOIN business b ON (ec.business_id = b.id)
                 OR EXISTS (select 1
                              from matching_entity_contacts mec
                             where mec.entity_id = e.id))
-           AND (($5 IS NULL AND $6 IS NULL
-                 AND $7 IS NULL AND $8 IS NULL
-                 AND $9 IS NULL)
+           AND (
+                COALESCE($5, $6, $7, $8) IS NULL
                 OR EXISTS (select 1
                              from matching_locations m
                              join eca_to_location etl ON m.id = etl.location_id
@@ -385,6 +385,9 @@ LEFT JOIN business b ON (ec.business_id = b.id)
                              join entity_to_location etl
                                   ON m.id = etl.location_id
                             where etl.entity_id = e.id))
+           AND ($9 IS NULL
+                OR entity_country.short_name ILIKE $9
+                OR entity_country.name ILIKE $9 || '%')
            AND ($12 IS NULL
                 OR ec.business_id = $12)
            AND ($11 IS NULL
@@ -614,7 +617,7 @@ entity class.$$;
 CREATE OR REPLACE FUNCTION company__get (in_entity_id int)
 RETURNS company_entity AS
 $$
-        SELECT c.entity_id, e.entity_class, c.legal_name, c.tax_id, c.sales_tax_id,
+        SELECT c.entity_id, c.legal_name, c.tax_id, c.sales_tax_id,
                c.license_number, c.sic_code, e.control_code, e.country_id
           FROM company c
           JOIN entity e ON e.id = c.entity_id
@@ -627,7 +630,7 @@ $$ Returns all attributes for the company attached to the entity.$$;
 CREATE OR REPLACE FUNCTION company__get_by_cc (in_control_code text)
 RETURNS company_entity AS
 $$
-        SELECT c.entity_id, e.entity_class, c.legal_name, c.tax_id, c.sales_tax_id,
+        SELECT c.entity_id, c.legal_name, c.tax_id, c.sales_tax_id,
                c.license_number, c.sic_code, e.control_code, e.country_id
           FROM company c
           JOIN entity e ON e.id = c.entity_id
@@ -727,11 +730,18 @@ DROP FUNCTION IF EXISTS company__save (
     in_sales_tax_id text, in_license_number text
 );
 
-CREATE OR REPLACE FUNCTION company__save (
+DROP FUNCTION IF EXISTS company__save (
     in_control_code text, in_entity_class int,
     in_legal_name text, in_tax_id TEXT,
     in_entity_id int, in_sic_code text,in_country_id int,
     in_sales_tax_id text, in_license_number text
+);
+
+CREATE OR REPLACE FUNCTION company__save (
+    in_control_code text,
+    in_legal_name text, in_tax_id TEXT,
+    in_entity_id int, in_sic_code text,in_country_id int,
+    in_sales_tax_id text, in_license_number text
 ) RETURNS company AS $$
 DECLARE t_entity_id INT;
         t_control_code TEXT;
@@ -746,7 +756,6 @@ BEGIN
 
         UPDATE entity
         SET name = in_legal_name,
-                entity_class = in_entity_class,
                 control_code = t_control_code,
                 country_id   = in_country_id
         WHERE id = in_entity_id;
@@ -754,8 +763,8 @@ BEGIN
         IF FOUND THEN
                 t_entity_id = in_entity_id;
         ELSE
-                INSERT INTO entity (name, entity_class, control_code,country_id)
-                VALUES (in_legal_name, in_entity_class, t_control_code,in_country_id);
+                INSERT INTO entity (name, control_code,country_id)
+                VALUES (in_legal_name, t_control_code,in_country_id);
                 t_entity_id := currval('entity_id_seq');
         END IF;
 
@@ -781,7 +790,7 @@ END;
 $$ LANGUAGE PLPGSQL;
 
 COMMENT ON  FUNCTION company__save (
-    in_control_code text, in_entity_class int,
+    in_control_code text,
     in_legal_name text, in_tax_id TEXT,
     in_entity_id int, in_sic_code text,in_country_id int,
     in_sales_tax_id text, in_license_number text
@@ -1196,25 +1205,31 @@ create or replace function _entity_location_save(
 ) returns int AS $$
 
     DECLARE
-        l_row location;
         l_id INT;
-        t_company_id int;
     BEGIN
-        SELECT id INTO t_company_id
-        FROM company WHERE entity_id = in_entity_id;
-
-        DELETE FROM entity_to_location
-        WHERE entity_id = in_entity_id
-                AND location_class = in_location_class
-                AND location_id = in_location_id;
-
-        SELECT location_save(NULL, in_line_one, in_line_two, in_line_three, in_city,
-                in_state, in_mail_code, in_country_id)
+      SELECT location_save(
+        NULL,
+        in_line_one,
+        in_line_two,
+        in_line_three,
+        in_city,
+        in_state,
+        in_mail_code,
+        in_country_id
+      )
         INTO l_id;
 
-        INSERT INTO entity_to_location
-                (entity_id, location_class, location_id)
-        VALUES  (in_entity_id, in_location_class, l_id);
+      UPDATE entity_to_location
+         SET location_class = in_location_class,
+             location_id = l_id
+       WHERE entity_id = in_entity_id
+         AND location_class = in_location_class
+         AND location_id = in_location_id;
+
+      IF NOT FOUND THEN
+        INSERT INTO entity_to_location (entity_id, location_class, location_id)
+        VALUES (in_entity_id, in_location_class, l_id);
+      END IF;
 
         RETURN l_id;
     END;
@@ -1239,41 +1254,28 @@ create or replace function eca__location_save(
 ) returns int AS $$
 
     DECLARE
-        l_row location;
         l_id INT;
-        l_orig_id INT;
     BEGIN
+        SELECT location_save(
+          NULL,
+          in_line_one,
+          in_line_two,
+          in_line_three,
+          in_city,
+          in_state,
+          in_mail_code,
+          in_country_id
+        )
+          INTO l_id;
 
         UPDATE eca_to_location
-           SET location_class = in_location_class
+           SET location_class = in_location_class,
+               location_id = l_id
          WHERE credit_id = in_credit_id
            AND location_class = in_old_location_class
            AND location_id = in_id;
 
-         IF FOUND THEN
-            SELECT location_save(
-                in_id,
-                in_line_one,
-                in_line_two,
-                in_line_three,
-                in_city,
-                in_state,
-                in_mail_code,
-                in_country_id
-            )
-                INTO l_id;
-        ELSE
-            SELECT location_save(
-                NULL,
-                in_line_one,
-                in_line_two,
-                in_line_three,
-                in_city,
-                in_state,
-                in_mail_code,
-                in_country_id
-            )
-                INTO l_id;
+         IF NOT FOUND THEN
             INSERT INTO eca_to_location
                         (credit_id, location_class, location_id)
                 VALUES  (in_credit_id, in_location_class, l_id);
