@@ -656,6 +656,9 @@ SELECT lsmb__create_role('draft_modify',
                          This role allows modification of existing draft (= saved) transactions.
                          $DOC$
 );
+SELECT lsmb__grant_exec('draft_modify', 'draft__delete_lines(int)');
+SELECT lsmb__grant_exec('draft_modify', 'draft_delete(int)');
+
 SELECT lsmb__create_role('draft_post',
                          $DOC$
                          This role allows posting of saved transactions to the ledger.
@@ -721,7 +724,7 @@ SELECT lsmb__create_role('ar_invoice_create',
 SELECT lsmb__grant_role('ar_invoice_create', 'ar_transaction_create');
 -- ### old code needs UPDATE
 SELECT lsmb__grant_perms('ar_invoice_create', tname, ptype)
-  FROM unnest('{invoice,new_shipto,business_unit_inv}'::text[]) tname
+  FROM unnest('{invoice,business_unit_inv}'::text[]) tname
  CROSS JOIN unnest('{SELECT,INSERT,UPDATE}'::text[]) ptype;
 
 SELECT lsmb__grant_menu('ar_invoice_create', 3, 'allow');
@@ -783,14 +786,13 @@ SELECT lsmb__create_role('sales_order_create',
 SELECT lsmb__grant_role('sales_order_create', 'contact_read');
 SELECT lsmb__grant_role('sales_order_create', 'exchangerate_edit');
 SELECT lsmb__grant_perms('sales_order_create', obj, 'ALL')
-  FROM unnest(array['oe'::text, 'oe_id_seq', 'warehouse_inventory', 'orderitems_id_seq'])
+  FROM unnest(array['oe'::text, 'oe_tax', 'oe_id_seq', 'warehouse_inventory', 'orderitems_id_seq'])
        obj;
 SELECT lsmb__grant_perms('sales_order_create', 'oe_id_seq', 'ALL');
 SELECT lsmb__grant_perms('sales_order_create', 'orderitems', 'INSERT');
 SELECT lsmb__grant_perms('sales_order_create', 'orderitems', 'UPDATE');
 SELECT lsmb__grant_perms('sales_order_create', 'business_unit_oitem', 'INSERT');
 SELECT lsmb__grant_perms('sales_order_create', 'business_unit_oitem', 'UPDATE');
-SELECT lsmb__grant_perms('sales_order_create', 'new_shipto_id_seq', 'ALL');
 SELECT lsmb__grant_menu('sales_order_create', '51', 'allow');
 
 SELECT lsmb__create_role('sales_order_edit',
@@ -800,8 +802,6 @@ SELECT lsmb__create_role('sales_order_edit',
 );
 SELECT lsmb__grant_perms('sales_order_edit', 'orderitems', 'DELETE');
 SELECT lsmb__grant_perms('sales_order_edit', 'business_unit_oitem', 'DELETE');
-SELECT lsmb__grant_perms('sales_order_edit', 'new_shipto', 'DELETE');
-SELECT lsmb__grant_perms('sales_order_edit', 'new_shipto_id_seq', 'ALL');
 
 SELECT lsmb__create_role('sales_order_delete',
                          $DOC$
@@ -824,8 +824,7 @@ SELECT lsmb__create_role('rfq_delete',
                          $DOC$
 );
 SELECT lsmb__grant_perms(dt || '_delete', obj, 'DELETE')
-  FROM unnest(ARRAY['oe'::TEXT, 'orderitems', 'business_unit_oitem',
-                    'new_shipto']) obj
+  FROM unnest(ARRAY['oe'::TEXT, 'orderitems', 'business_unit_oitem']) obj
  CROSS
   JOIN unnest(array['sales_order'::text, 'sales_quotation', 'purchase_order',
               'rfq']) dt;
@@ -843,7 +842,6 @@ SELECT lsmb__grant_perms('sales_quotation_create', obj, 'ALL')
 SELECT lsmb__grant_perms('sales_quotation_create', obj, ptype)
   FROM unnest(array['orderitems'::text, 'business_unit_oitem']) obj,
        unnest(array['INSERT'::text, 'UPDATE']) ptype;
-SELECT lsmb__grant_perms('sales_quotation_create', 'new_shipto_id_seq', 'ALL');
 
 SELECT lsmb__grant_menu('sales_quotation_create', 68, 'allow');
 
@@ -1001,7 +999,6 @@ SELECT lsmb__grant_perms('purchase_order_create', obj, ptype)
 SELECT lsmb__grant_perms('purchase_order_create', obj, 'ALL')
   FROM unnest(array['oe_id_seq'::text, 'orderitems_id_seq', 'warehouse_inventory',
                     'warehouse_inventory_entry_id_seq']) obj;
-SELECT lsmb__grant_perms('purchase_order_create', 'new_shipto_id_seq', 'ALL');
 SELECT lsmb__grant_menu('purchase_order_create', 52, 'allow');
 
 SELECT lsmb__create_role('purchase_order_edit',
@@ -1010,9 +1007,7 @@ SELECT lsmb__create_role('purchase_order_edit',
                          $DOC$
 );
 SELECT lsmb__grant_perms('purchase_order_edit', obj, 'DELETE')
-  FROM unnest(array['oe'::text, 'orderitems', 'business_unit_oitem',
-                    'new_shipto']) obj;
-SELECT lsmb__grant_perms('purchase_order_edit', 'new_shipto_id_seq', 'ALL');
+  FROM unnest(array['oe'::text, 'orderitems', 'business_unit_oitem']) obj;
 
 SELECT lsmb__create_role('rfq_create',
                          $DOC$
@@ -1027,7 +1022,6 @@ SELECT lsmb__grant_perms('rfq_create', 'orderitems_id_seq', 'ALL');
 SELECT lsmb__grant_perms('rfq_create', obj, ptype)
   FROM unnest(array['oe'::text, 'orderitems', 'business_unit_oitem']) obj,
        unnest(array['INSERT'::text, 'UPDATE']) ptype;
-SELECT lsmb__grant_perms('rfq_create', 'new_shipto_id_seq', 'ALL');
 
 SELECT lsmb__create_role('purchase_order_list',
                          $DOC$
@@ -1968,11 +1962,9 @@ SELECT lsmb__grant_perms('base_user', obj, 'SELECT')
                     'business', 'template',
                     --###TODO: Add table for advisory rates
                     --'exchangerate',
-                    'new_shipto', 'tax',
+                    'tax',
                     'entity_employee', 'jcitems', 'salutation', 'assembly']) obj;
 
-SELECT lsmb__grant_perms('base_user', 'new_shipto', 'UPDATE');
-
 SELECT lsmb__grant_perms('base_user', obj, 'SELECT')
   FROM unnest(array['partstax'::text, 'partscustomer',
                     'account_heading_descendant',
@@ -2027,11 +2019,6 @@ END IF;
 END;
 $$ LANGUAGE PLPGSQL;
 
-DROP TRIGGER IF EXISTS eclass_perms_check ON entity;
-CREATE TRIGGER eclass_perms_check
-BEFORE INSERT OR UPDATE OR DELETE ON entity
-FOR EACH ROW EXECUTE PROCEDURE tg_enforce_perms_eclass();
-
 DROP TRIGGER IF EXISTS eclass_perms_check ON entity_credit_account;
 CREATE TRIGGER eclass_perms_check
 BEFORE INSERT OR UPDATE OR DELETE ON entity_credit_account
